CREATE FUNCTION plpgsql_call_handler() RETURNS language_handler AS '$libdir/plpgsql' LANGUAGE C;
CREATE FUNCTION plpgsql_validator(oid) RETURNS void AS '$libdir/plpgsql' LANGUAGE C;
CREATE TRUSTED PROCEDURAL LANGUAGE plpgsql HANDLER plpgsql_call_handler VALIDATOR plpgsql_validator;
CREATE OR REPLACE FUNCTION mc_timestamp_updating() RETURNS TRIGGER AS $timestamp_updating_function$
BEGIN
  NEW._timestamp := now(); -- hack comment
  return NEW; -- hack comment
END; -- hack comment
$timestamp_updating_function$ LANGUAGE plpgsql;
CREATE TABLE change_table (_rowid bigserial PRIMARY KEY, table_name varchar(40) NOT NULL);
CREATE TABLE change_log (_rowid bigserial PRIMARY KEY, _timestamp timestamp with time zone, table_id bigint NOT NULL,primary_key bigint NOT NULL,operation CHAR(1) NOT NULL,changed_columns varchar, client_id varchar(64), user_id bigint);
CREATE INDEX change_log_table_id_index ON change_log (table_id);
CREATE INDEX change_log_primary_key_index ON change_log (primary_key);
CREATE TRIGGER change_log_timestamp_updating BEFORE INSERT OR UPDATE ON change_log FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE AGGREGATE aggarray (basetype = anyelement, sfunc = array_append,stype = anyarray, initcond = '{}' );
CREATE OR REPLACE FUNCTION mc_addmembertoset(character varying, integer)
  RETURNS character varying AS
$BODY$
  DECLARE 	
    existingstring ALIAS FOR $1; -- hack comment
    newvalue ALIAS FOR $2; -- Hack Comment
    tempstring varchar; -- hack comment 	
    sortvalues integer[]; -- Hack Comment
  BEGIN
    IF char_length($1)>0
    THEN
    tempstring := mc_convert_pipes_to_array_string(existingstring); -- Hack Comment
    tempstring := tempstring || ',' || newvalue; -- Hack Comment
    sortvalues := string_to_array(tempstring,','); -- Hack Comment
    tempstring := mc_getpackedstring(sortvalues); -- Hack Comment
    
    RETURN mc_convert_array_string_to_pipes(tempstring); -- Hack Comment
  ELSE
    RETURN '|' || $2 || '|'; -- hack comment 	
  END IF; -- Hack Comment
 END
$BODY$ 
  LANGUAGE 'plpgsql' IMMUTABLE 
  COST 100;
CREATE OR REPLACE FUNCTION mc_removememberfromset(character varying, integer)
  RETURNS character varying AS
$BODY$
	SELECT replace($1,'|' || $2 || '|','')
$BODY$
  LANGUAGE 'sql' IMMUTABLE
  COST 100;
CREATE OR REPLACE FUNCTION mc_convert_array_string_to_pipes(string character varying) 
  RETURNS character varying AS
$BODY$
	SELECT '|' || replace($1,',','||') || '|'
$BODY$ 
  LANGUAGE 'sql' IMMUTABLE
  COST 100;
CREATE OR REPLACE FUNCTION mc_convert_pipes_to_array_string(string character varying)
  RETURNS character varying AS
$BODY$
  SELECT replace(replace($1,'||',','),'|','')
$BODY$
  LANGUAGE 'sql' IMMUTABLE
  COST 100;
CREATE OR REPLACE FUNCTION mc_getpackedstring(anyarray)
  RETURNS character varying AS
$BODY$
    SELECT array_to_string(aggarray(Element),',') FROM (SELECT DISTINCT ($1)[s] as Element FROM
    generate_series(1,array_upper($1, 1)) as s ORDER BY Element) AS Alias; -- Hack Comment
$BODY$
  LANGUAGE 'sql' IMMUTABLE
  COST 100;
CREATE TABLE ABSyncMap (_timestamp timestamp with time zone, abID varchar(64), _rowid bigint PRIMARY KEY NOT NULL, date timestamp with time zone, entityID bigint, entityTypeCode integer NOT NULL DEFAULT '0', lastSyncDate timestamp with time zone, organizationID bigint, userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ABSyncMap_entityID_index ON ABSyncMap (entityID);
CREATE INDEX ABSyncMap_organizationID_index ON ABSyncMap (organizationID);
CREATE INDEX ABSyncMap_userID_index ON ABSyncMap (userID);
CREATE INDEX ABSyncMap_deletionUserID_index ON ABSyncMap (deletionUserID);
CREATE INDEX ABSyncMap_deletionDate_index ON ABSyncMap (deletionDate);
CREATE INDEX ABSyncMap_deletionIdentifier_index ON ABSyncMap (deletionIdentifier);
CREATE SEQUENCE ABSyncMap_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ABSyncMap._rowid;
ALTER TABLE ABSyncMap ALTER COLUMN _rowid SET DEFAULT nextval('ABSyncMap_nextPK');
CREATE TRIGGER ABSyncMap_timestamp_updating BEFORE INSERT OR UPDATE ON ABSyncMap FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ActionItem (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, actionSetID bigint, actionType integer NOT NULL DEFAULT '0', assignToUserID bigint, billingRateID bigint, categoryID bigint, dueOffset integer NOT NULL DEFAULT '0', dueSkipRule varchar(512), durationMinutes integer NOT NULL DEFAULT '0', name varchar(255), ordering integer NOT NULL DEFAULT '0', remindBeforeMinutes integer NOT NULL DEFAULT '0', remindHour integer NOT NULL DEFAULT '0', remindMinutes integer NOT NULL DEFAULT '0', startHour integer NOT NULL DEFAULT '0', startMinutes integer NOT NULL DEFAULT '0', startOffset bigint, startSkipRule varchar(512), useReminder integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ActionItem_actionSetID_index ON ActionItem (actionSetID);
CREATE INDEX ActionItem_assignToUserID_index ON ActionItem (assignToUserID);
CREATE INDEX ActionItem_billingRateID_index ON ActionItem (billingRateID);
CREATE INDEX ActionItem_categoryID_index ON ActionItem (categoryID);
CREATE INDEX ActionItem_deletionUserID_index ON ActionItem (deletionUserID);
CREATE INDEX ActionItem_deletionDate_index ON ActionItem (deletionDate);
CREATE INDEX ActionItem_deletionIdentifier_index ON ActionItem (deletionIdentifier);
CREATE SEQUENCE ActionItem_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ActionItem._rowid;
ALTER TABLE ActionItem ALTER COLUMN _rowid SET DEFAULT nextval('ActionItem_nextPK');
CREATE TRIGGER ActionItem_timestamp_updating BEFORE INSERT OR UPDATE ON ActionItem FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ActionSet (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, detail varchar(1023), forContact integer NOT NULL DEFAULT '0', forGroup integer NOT NULL DEFAULT '0', forOpportunity integer NOT NULL DEFAULT '0', forOrganization integer NOT NULL DEFAULT '0', forProject integer NOT NULL DEFAULT '0', name varchar(255), ordering integer NOT NULL DEFAULT '0', reverseSet integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ActionSet_deletionUserID_index ON ActionSet (deletionUserID);
CREATE INDEX ActionSet_deletionDate_index ON ActionSet (deletionDate);
CREATE INDEX ActionSet_deletionIdentifier_index ON ActionSet (deletionIdentifier);
CREATE SEQUENCE ActionSet_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ActionSet._rowid;
ALTER TABLE ActionSet ALTER COLUMN _rowid SET DEFAULT nextval('ActionSet_nextPK');
CREATE TRIGGER ActionSet_timestamp_updating BEFORE INSERT OR UPDATE ON ActionSet FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE AlertObject (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, alertTypeCode integer NOT NULL DEFAULT '0', createDate timestamp with time zone, entityID bigint, entityName varchar(64), isReadCode integer NOT NULL DEFAULT '0', isShownCode integer NOT NULL DEFAULT '0', messageBlob text, reasonString varchar(4096), receivingUserID bigint, sendingUserID bigint, userInfoStorage bytea, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX AlertObject_receivingUserID_index ON AlertObject (receivingUserID);
CREATE INDEX AlertObject_sendingUserID_index ON AlertObject (sendingUserID);
CREATE INDEX AlertObject_deletionUserID_index ON AlertObject (deletionUserID);
CREATE INDEX AlertObject_deletionDate_index ON AlertObject (deletionDate);
CREATE INDEX AlertObject_deletionIdentifier_index ON AlertObject (deletionIdentifier);
CREATE SEQUENCE AlertObject_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY AlertObject._rowid;
ALTER TABLE AlertObject ALTER COLUMN _rowid SET DEFAULT nextval('AlertObject_nextPK');
CREATE TRIGGER AlertObject_timestamp_updating BEFORE INSERT OR UPDATE ON AlertObject FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE BillingRate (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, hourlyRate money, minimumCharge money, minimumMinutes integer NOT NULL DEFAULT '0', minimumType integer NOT NULL DEFAULT '0', name varchar(255), ordering integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX BillingRate_deletionUserID_index ON BillingRate (deletionUserID);
CREATE INDEX BillingRate_deletionDate_index ON BillingRate (deletionDate);
CREATE INDEX BillingRate_deletionIdentifier_index ON BillingRate (deletionIdentifier);
CREATE SEQUENCE BillingRate_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY BillingRate._rowid;
ALTER TABLE BillingRate ALTER COLUMN _rowid SET DEFAULT nextval('BillingRate_nextPK');
CREATE TRIGGER BillingRate_timestamp_updating BEFORE INSERT OR UPDATE ON BillingRate FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Calendar (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, createDate timestamp with time zone, ownerID bigint, rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Calendar_ownerID_index ON Calendar (ownerID);
CREATE INDEX Calendar_deletionUserID_index ON Calendar (deletionUserID);
CREATE INDEX Calendar_deletionDate_index ON Calendar (deletionDate);
CREATE INDEX Calendar_deletionIdentifier_index ON Calendar (deletionIdentifier);
CREATE SEQUENCE Calendar_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Calendar._rowid;
ALTER TABLE Calendar ALTER COLUMN _rowid SET DEFAULT nextval('Calendar_nextPK');
CREATE TRIGGER Calendar_timestamp_updating BEFORE INSERT OR UPDATE ON Calendar FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Category (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, createDate timestamp with time zone, encodedColor varchar(1024), forContact integer NOT NULL DEFAULT '0', forGroup integer NOT NULL DEFAULT '0', forNote integer NOT NULL DEFAULT '0', forOpportunity integer NOT NULL DEFAULT '0', forOrganization integer NOT NULL DEFAULT '0', forProject integer NOT NULL DEFAULT '0', forTask integer NOT NULL DEFAULT '0', forTimeblock integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, name varchar(255), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Category_deletionUserID_index ON Category (deletionUserID);
CREATE INDEX Category_deletionDate_index ON Category (deletionDate);
CREATE INDEX Category_deletionIdentifier_index ON Category (deletionIdentifier);
CREATE SEQUENCE Category_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Category._rowid;
ALTER TABLE Category ALTER COLUMN _rowid SET DEFAULT nextval('Category_nextPK');
CREATE TRIGGER Category_timestamp_updating BEFORE INSERT OR UPDATE ON Category FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ConnectorMap (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, contactID bigint, estimateID bigint, foreignAppName varchar(255), foreignDatabase varchar(512), foreignEntityType varchar(255), foreignID varchar(512), groupID bigint, lastPullDate timestamp with time zone, lastPushDate timestamp with time zone, lineItemID bigint, noteID bigint, opportunityID bigint, organizationID bigint, projectID bigint, taskID bigint, timeblockID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ConnectorMap_contactID_index ON ConnectorMap (contactID);
CREATE INDEX ConnectorMap_estimateID_index ON ConnectorMap (estimateID);
CREATE INDEX ConnectorMap_groupID_index ON ConnectorMap (groupID);
CREATE INDEX ConnectorMap_lineItemID_index ON ConnectorMap (lineItemID);
CREATE INDEX ConnectorMap_noteID_index ON ConnectorMap (noteID);
CREATE INDEX ConnectorMap_opportunityID_index ON ConnectorMap (opportunityID);
CREATE INDEX ConnectorMap_organizationID_index ON ConnectorMap (organizationID);
CREATE INDEX ConnectorMap_projectID_index ON ConnectorMap (projectID);
CREATE INDEX ConnectorMap_taskID_index ON ConnectorMap (taskID);
CREATE INDEX ConnectorMap_timeblockID_index ON ConnectorMap (timeblockID);
CREATE INDEX ConnectorMap_deletionUserID_index ON ConnectorMap (deletionUserID);
CREATE INDEX ConnectorMap_deletionDate_index ON ConnectorMap (deletionDate);
CREATE INDEX ConnectorMap_deletionIdentifier_index ON ConnectorMap (deletionIdentifier);
CREATE SEQUENCE ConnectorMap_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ConnectorMap._rowid;
ALTER TABLE ConnectorMap ALTER COLUMN _rowid SET DEFAULT nextval('ConnectorMap_nextPK');
CREATE TRIGGER ConnectorMap_timestamp_updating BEFORE INSERT OR UPDATE ON ConnectorMap FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Contact (_timestamp timestamp with time zone, alias varchar(255), anniversaryDay integer NOT NULL DEFAULT '0', anniversaryMonth integer NOT NULL DEFAULT '0', anniversaryYear integer NOT NULL DEFAULT '0', assignedToID bigint, birthDay integer NOT NULL DEFAULT '0', birthMonth integer NOT NULL DEFAULT '0', birthYear integer NOT NULL DEFAULT '0', cachedDefaultOrganizationName varchar(256), cachedDefaultRoleName varchar(256), cachedName varchar(512), categoryID bigint, _rowid bigint PRIMARY KEY NOT NULL, createDate timestamp with time zone, createdByID bigint, creditation varchar(255), defaultEAddressID bigint, defaultGeoAddressID bigint, defaultNoteID bigint, defaultPhoneID bigint, defaultRoleID bigint, defaultSecondPhoneID bigint, detailsID bigint, extra1 varchar(255), extra10 varchar(255), extra11 varchar(255), extra12 varchar(255), extra2 varchar(255), extra3 varchar(255), extra4 varchar(255), extra5 varchar(255), extra6 varchar(255), extra7 varchar(255), extra8 varchar(255), extra9 varchar(255), extraDate1 timestamp with time zone, extraDate2 timestamp with time zone, extraDate3 timestamp with time zone, extraDate4 timestamp with time zone, firstname varchar(255), flagged integer NOT NULL DEFAULT '0', hobbies varchar(1024), imageDataID bigint, inShortcut integer NOT NULL DEFAULT '0', isPrivate integer NOT NULL DEFAULT '0', lastname varchar(255), leadSourceID bigint, level integer NOT NULL DEFAULT '0', middlename varchar(255), modifyDate timestamp with time zone, nickname varchar(255), ordering integer NOT NULL DEFAULT '0', permissionMask integer NOT NULL DEFAULT '0', quickSearchID bigint, relationshipToMe varchar(255), rootID bigint, salutationCode integer NOT NULL DEFAULT '0', salutationString varchar(255), sourceImportID varchar(128), suffix varchar(255), tagline varchar(1024), teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), tickerSymbol varchar(64), visibilityPresetID bigint, individualSalutation varchar(128), deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Contact_assignedToID_index ON Contact (assignedToID);
CREATE INDEX Contact_categoryID_index ON Contact (categoryID);
CREATE INDEX Contact_createdByID_index ON Contact (createdByID);
CREATE INDEX Contact_defaultEAddressID_index ON Contact (defaultEAddressID);
CREATE INDEX Contact_defaultGeoAddressID_index ON Contact (defaultGeoAddressID);
CREATE INDEX Contact_defaultNoteID_index ON Contact (defaultNoteID);
CREATE INDEX Contact_defaultPhoneID_index ON Contact (defaultPhoneID);
CREATE INDEX Contact_defaultRoleID_index ON Contact (defaultRoleID);
CREATE INDEX Contact_defaultSecondPhoneID_index ON Contact (defaultSecondPhoneID);
CREATE INDEX Contact_detailsID_index ON Contact (detailsID);
CREATE INDEX Contact_imageDataID_index ON Contact (imageDataID);
CREATE INDEX Contact_leadSourceID_index ON Contact (leadSourceID);
CREATE INDEX Contact_quickSearchID_index ON Contact (quickSearchID);
CREATE INDEX Contact_visibilityPresetID_index ON Contact (visibilityPresetID);
CREATE INDEX Contact_deletionUserID_index ON Contact (deletionUserID);
CREATE INDEX Contact_deletionDate_index ON Contact (deletionDate);
CREATE INDEX Contact_deletionIdentifier_index ON Contact (deletionIdentifier);
CREATE SEQUENCE Contact_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Contact._rowid;
ALTER TABLE Contact ALTER COLUMN _rowid SET DEFAULT nextval('Contact_nextPK');
CREATE TRIGGER Contact_timestamp_updating BEFORE INSERT OR UPDATE ON Contact FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ContactCorrespondenceJoin (_timestamp timestamp with time zone, contactID bigint NOT NULL, correspondenceID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ContactCorrespondenceJoin_contactID_index ON ContactCorrespondenceJoin (contactID);
CREATE INDEX ContactCorrespondenceJoin_correspondenceID_index ON ContactCorrespondenceJoin (correspondenceID);
CREATE INDEX ContactCorrespondenceJoin_deletionUserID_index ON ContactCorrespondenceJoin (deletionUserID);
CREATE INDEX ContactCorrespondenceJoin_deletionDate_index ON ContactCorrespondenceJoin (deletionDate);
CREATE INDEX ContactCorrespondenceJoin_deletionIdentifier_index ON ContactCorrespondenceJoin (deletionIdentifier);
CREATE SEQUENCE ContactCorrespondenceJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ContactCorrespondenceJoin._rowid;
ALTER TABLE ContactCorrespondenceJoin ALTER COLUMN _rowid SET DEFAULT nextval('ContactCorrespondenceJoin_nextPK');
CREATE TRIGGER ContactCorrespondenceJoin_timestamp_updating BEFORE INSERT OR UPDATE ON ContactCorrespondenceJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ContactGroupJoin (_timestamp timestamp with time zone, contactID bigint NOT NULL, groupID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ContactGroupJoin_contactID_index ON ContactGroupJoin (contactID);
CREATE INDEX ContactGroupJoin_groupID_index ON ContactGroupJoin (groupID);
CREATE INDEX ContactGroupJoin_deletionUserID_index ON ContactGroupJoin (deletionUserID);
CREATE INDEX ContactGroupJoin_deletionDate_index ON ContactGroupJoin (deletionDate);
CREATE INDEX ContactGroupJoin_deletionIdentifier_index ON ContactGroupJoin (deletionIdentifier);
CREATE SEQUENCE ContactGroupJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ContactGroupJoin._rowid;
ALTER TABLE ContactGroupJoin ALTER COLUMN _rowid SET DEFAULT nextval('ContactGroupJoin_nextPK');
CREATE TRIGGER ContactGroupJoin_timestamp_updating BEFORE INSERT OR UPDATE ON ContactGroupJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ContactKeywordJoin (_timestamp timestamp with time zone, contactID bigint NOT NULL, keywordID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ContactKeywordJoin_contactID_index ON ContactKeywordJoin (contactID);
CREATE INDEX ContactKeywordJoin_keywordID_index ON ContactKeywordJoin (keywordID);
CREATE INDEX ContactKeywordJoin_deletionUserID_index ON ContactKeywordJoin (deletionUserID);
CREATE INDEX ContactKeywordJoin_deletionDate_index ON ContactKeywordJoin (deletionDate);
CREATE INDEX ContactKeywordJoin_deletionIdentifier_index ON ContactKeywordJoin (deletionIdentifier);
CREATE SEQUENCE ContactKeywordJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ContactKeywordJoin._rowid;
ALTER TABLE ContactKeywordJoin ALTER COLUMN _rowid SET DEFAULT nextval('ContactKeywordJoin_nextPK');
CREATE TRIGGER ContactKeywordJoin_timestamp_updating BEFORE INSERT OR UPDATE ON ContactKeywordJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ContactNoteJoin (_timestamp timestamp with time zone, contactID bigint NOT NULL, noteID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ContactNoteJoin_contactID_index ON ContactNoteJoin (contactID);
CREATE INDEX ContactNoteJoin_noteID_index ON ContactNoteJoin (noteID);
CREATE INDEX ContactNoteJoin_deletionUserID_index ON ContactNoteJoin (deletionUserID);
CREATE INDEX ContactNoteJoin_deletionDate_index ON ContactNoteJoin (deletionDate);
CREATE INDEX ContactNoteJoin_deletionIdentifier_index ON ContactNoteJoin (deletionIdentifier);
CREATE SEQUENCE ContactNoteJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ContactNoteJoin._rowid;
ALTER TABLE ContactNoteJoin ALTER COLUMN _rowid SET DEFAULT nextval('ContactNoteJoin_nextPK');
CREATE TRIGGER ContactNoteJoin_timestamp_updating BEFORE INSERT OR UPDATE ON ContactNoteJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ContactTaskJoin (_timestamp timestamp with time zone, contactID bigint NOT NULL, taskID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ContactTaskJoin_contactID_index ON ContactTaskJoin (contactID);
CREATE INDEX ContactTaskJoin_taskID_index ON ContactTaskJoin (taskID);
CREATE INDEX ContactTaskJoin_deletionUserID_index ON ContactTaskJoin (deletionUserID);
CREATE INDEX ContactTaskJoin_deletionDate_index ON ContactTaskJoin (deletionDate);
CREATE INDEX ContactTaskJoin_deletionIdentifier_index ON ContactTaskJoin (deletionIdentifier);
CREATE SEQUENCE ContactTaskJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ContactTaskJoin._rowid;
ALTER TABLE ContactTaskJoin ALTER COLUMN _rowid SET DEFAULT nextval('ContactTaskJoin_nextPK');
CREATE TRIGGER ContactTaskJoin_timestamp_updating BEFORE INSERT OR UPDATE ON ContactTaskJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ContactTimeblockJoin (_timestamp timestamp with time zone, contactID bigint NOT NULL, timeblockID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ContactTimeblockJoin_contactID_index ON ContactTimeblockJoin (contactID);
CREATE INDEX ContactTimeblockJoin_timeblockID_index ON ContactTimeblockJoin (timeblockID);
CREATE INDEX ContactTimeblockJoin_deletionUserID_index ON ContactTimeblockJoin (deletionUserID);
CREATE INDEX ContactTimeblockJoin_deletionDate_index ON ContactTimeblockJoin (deletionDate);
CREATE INDEX ContactTimeblockJoin_deletionIdentifier_index ON ContactTimeblockJoin (deletionIdentifier);
CREATE SEQUENCE ContactTimeblockJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ContactTimeblockJoin._rowid;
ALTER TABLE ContactTimeblockJoin ALTER COLUMN _rowid SET DEFAULT nextval('ContactTimeblockJoin_nextPK');
CREATE TRIGGER ContactTimeblockJoin_timestamp_updating BEFORE INSERT OR UPDATE ON ContactTimeblockJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Correspondence (_timestamp timestamp with time zone, bcc varchar(1024), cc varchar(1024), _rowid bigint PRIMARY KEY NOT NULL, correspondenceTemplateID bigint, createDate timestamp with time zone, date timestamp with time zone, largeDataID bigint, opportunityID bigint, projectID bigint, rootID bigint, sendReceiveType integer NOT NULL DEFAULT '0', storageLocation varchar(1024), storageType integer NOT NULL DEFAULT '0', subject varchar(1024), type integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Correspondence_correspondenceTemplateID_index ON Correspondence (correspondenceTemplateID);
CREATE INDEX Correspondence_largeDataID_index ON Correspondence (largeDataID);
CREATE INDEX Correspondence_opportunityID_index ON Correspondence (opportunityID);
CREATE INDEX Correspondence_projectID_index ON Correspondence (projectID);
CREATE INDEX Correspondence_deletionUserID_index ON Correspondence (deletionUserID);
CREATE INDEX Correspondence_deletionDate_index ON Correspondence (deletionDate);
CREATE INDEX Correspondence_deletionIdentifier_index ON Correspondence (deletionIdentifier);
CREATE SEQUENCE Correspondence_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Correspondence._rowid;
ALTER TABLE Correspondence ALTER COLUMN _rowid SET DEFAULT nextval('Correspondence_nextPK');
CREATE TRIGGER Correspondence_timestamp_updating BEFORE INSERT OR UPDATE ON Correspondence FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE CorrespondenceTemplate (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', application varchar(1024), _rowid bigint PRIMARY KEY NOT NULL, createDate timestamp with time zone, details varchar(1024), largeDataID bigint, mergeType integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, name varchar(256), ordering integer NOT NULL DEFAULT '0', rawTemplateLocation varchar(1024), requiredObjectType integer NOT NULL DEFAULT '0', rootID bigint, storageType integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX CorrespondenceTemplate_largeDataID_index ON CorrespondenceTemplate (largeDataID);
CREATE INDEX CorrespondenceTemplate_deletionUserID_index ON CorrespondenceTemplate (deletionUserID);
CREATE INDEX CorrespondenceTemplate_deletionDate_index ON CorrespondenceTemplate (deletionDate);
CREATE INDEX CorrespondenceTemplate_deletionIdentifier_index ON CorrespondenceTemplate (deletionIdentifier);
CREATE SEQUENCE CorrespondenceTemplate_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY CorrespondenceTemplate._rowid;
ALTER TABLE CorrespondenceTemplate ALTER COLUMN _rowid SET DEFAULT nextval('CorrespondenceTemplate_nextPK');
CREATE TRIGGER CorrespondenceTemplate_timestamp_updating BEFORE INSERT OR UPDATE ON CorrespondenceTemplate FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE CustomRecord (_timestamp timestamp with time zone, createDate timestamp with time zone, definitionID bigint, _rowid bigint PRIMARY KEY NOT NULL, customRecordSetID bigint, ordering integer NOT NULL DEFAULT '0', recordValue varchar(4096), deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX CustomRecord_definitionID_index ON CustomRecord (definitionID);
CREATE INDEX CustomRecord_customRecordSetID_index ON CustomRecord (customRecordSetID);
CREATE INDEX CustomRecord_deletionUserID_index ON CustomRecord (deletionUserID);
CREATE INDEX CustomRecord_deletionDate_index ON CustomRecord (deletionDate);
CREATE INDEX CustomRecord_deletionIdentifier_index ON CustomRecord (deletionIdentifier);
CREATE SEQUENCE CustomRecord_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY CustomRecord._rowid;
ALTER TABLE CustomRecord ALTER COLUMN _rowid SET DEFAULT nextval('CustomRecord_nextPK');
CREATE TRIGGER CustomRecord_timestamp_updating BEFORE INSERT OR UPDATE ON CustomRecord FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE CustomRecordDefinition (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, customRecordSetDefinitionID bigint, defaultValue varchar(4096), details varchar(1024), forContact integer NOT NULL DEFAULT '0', forGroup integer NOT NULL DEFAULT '0', forOpportunity integer NOT NULL DEFAULT '0', forOrganization integer NOT NULL DEFAULT '0', forProject integer NOT NULL DEFAULT '0', length integer NOT NULL DEFAULT '0', name varchar(256), options varchar(4096), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', rootID bigint, typeCode integer NOT NULL DEFAULT '0', uniqueInRecordSet integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX CustomRecordDefinition_customRecordSetDefinitionID_index ON CustomRecordDefinition (customRecordSetDefinitionID);
CREATE INDEX CustomRecordDefinition_deletionUserID_index ON CustomRecordDefinition (deletionUserID);
CREATE INDEX CustomRecordDefinition_deletionDate_index ON CustomRecordDefinition (deletionDate);
CREATE INDEX CustomRecordDefinition_deletionIdentifier_index ON CustomRecordDefinition (deletionIdentifier);
CREATE SEQUENCE CustomRecordDefinition_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY CustomRecordDefinition._rowid;
ALTER TABLE CustomRecordDefinition ALTER COLUMN _rowid SET DEFAULT nextval('CustomRecordDefinition_nextPK');
CREATE TRIGGER CustomRecordDefinition_timestamp_updating BEFORE INSERT OR UPDATE ON CustomRecordDefinition FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE CustomRecordSet (_timestamp timestamp with time zone, contactID bigint, createDate timestamp with time zone, customRecordSetDefinitionID bigint, _rowid bigint PRIMARY KEY NOT NULL, groupID bigint, isDefaultForContact integer NOT NULL DEFAULT '0', isDefaultForGoal integer NOT NULL DEFAULT '0', isDefaultForGroup integer NOT NULL DEFAULT '0', isDefaultForOrganization integer NOT NULL DEFAULT '0', name varchar(256), opportunityID bigint, organizationID bigint, projectID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX CustomRecordSet_contactID_index ON CustomRecordSet (contactID);
CREATE INDEX CustomRecordSet_customRecordSetDefinitionID_index ON CustomRecordSet (customRecordSetDefinitionID);
CREATE INDEX CustomRecordSet_groupID_index ON CustomRecordSet (groupID);
CREATE INDEX CustomRecordSet_opportunityID_index ON CustomRecordSet (opportunityID);
CREATE INDEX CustomRecordSet_organizationID_index ON CustomRecordSet (organizationID);
CREATE INDEX CustomRecordSet_projectID_index ON CustomRecordSet (projectID);
CREATE INDEX CustomRecordSet_deletionUserID_index ON CustomRecordSet (deletionUserID);
CREATE INDEX CustomRecordSet_deletionDate_index ON CustomRecordSet (deletionDate);
CREATE INDEX CustomRecordSet_deletionIdentifier_index ON CustomRecordSet (deletionIdentifier);
CREATE SEQUENCE CustomRecordSet_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY CustomRecordSet._rowid;
ALTER TABLE CustomRecordSet ALTER COLUMN _rowid SET DEFAULT nextval('CustomRecordSet_nextPK');
CREATE TRIGGER CustomRecordSet_timestamp_updating BEFORE INSERT OR UPDATE ON CustomRecordSet FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE CustomRecordSetDefinition (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, createOnAddForContact integer NOT NULL DEFAULT '0', createOnAddForGroup integer NOT NULL DEFAULT '0', createOnAddForOpportunity integer NOT NULL DEFAULT '0', createOnAddForOrganization integer NOT NULL DEFAULT '0', createOnAddForProject integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, details varchar(1024), encodedColor varchar(1024), forContact integer NOT NULL DEFAULT '0', forGroup integer NOT NULL DEFAULT '0', forOpportunity integer NOT NULL DEFAULT '0', forOrganization integer NOT NULL DEFAULT '0', forProject integer NOT NULL DEFAULT '0', isCustom integer NOT NULL DEFAULT '0', isUniquePerObject integer NOT NULL DEFAULT '0', name varchar(256), ordering integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX CustomRecordSetDefinition_deletionUserID_index ON CustomRecordSetDefinition (deletionUserID);
CREATE INDEX CustomRecordSetDefinition_deletionDate_index ON CustomRecordSetDefinition (deletionDate);
CREATE INDEX CustomRecordSetDefinition_deletionIdentifier_index ON CustomRecordSetDefinition (deletionIdentifier);
CREATE SEQUENCE CustomRecordSetDefinition_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY CustomRecordSetDefinition._rowid;
ALTER TABLE CustomRecordSetDefinition ALTER COLUMN _rowid SET DEFAULT nextval('CustomRecordSetDefinition_nextPK');
CREATE TRIGGER CustomRecordSetDefinition_timestamp_updating BEFORE INSERT OR UPDATE ON CustomRecordSetDefinition FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE DatabaseConfiguration (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, date timestamp with time zone, databaseType integer NOT NULL DEFAULT '0', lastUsedReplicationOffset integer NOT NULL DEFAULT '0', schemaNumber integer NOT NULL DEFAULT '0', primaryKeyOffset integer NOT NULL DEFAULT '0', fud timestamp with time zone, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX DatabaseConfiguration_deletionUserID_index ON DatabaseConfiguration (deletionUserID);
CREATE INDEX DatabaseConfiguration_deletionDate_index ON DatabaseConfiguration (deletionDate);
CREATE INDEX DatabaseConfiguration_deletionIdentifier_index ON DatabaseConfiguration (deletionIdentifier);
CREATE SEQUENCE DatabaseConfiguration_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY DatabaseConfiguration._rowid;
ALTER TABLE DatabaseConfiguration ALTER COLUMN _rowid SET DEFAULT nextval('DatabaseConfiguration_nextPK');
CREATE TRIGGER DatabaseConfiguration_timestamp_updating BEFORE INSERT OR UPDATE ON DatabaseConfiguration FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE DatabasePreference (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, name varchar(128), prefValue varchar(4096), deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX DatabasePreference_deletionUserID_index ON DatabasePreference (deletionUserID);
CREATE INDEX DatabasePreference_deletionDate_index ON DatabasePreference (deletionDate);
CREATE INDEX DatabasePreference_deletionIdentifier_index ON DatabasePreference (deletionIdentifier);
CREATE SEQUENCE DatabasePreference_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY DatabasePreference._rowid;
ALTER TABLE DatabasePreference ALTER COLUMN _rowid SET DEFAULT nextval('DatabasePreference_nextPK');
CREATE TRIGGER DatabasePreference_timestamp_updating BEFORE INSERT OR UPDATE ON DatabasePreference FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE DatabaseReplicant (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, date timestamp with time zone, replicantPrimaryMACAddress varchar(255), replicationKey integer NOT NULL DEFAULT '0', userID bigint, clientUUID varchar(255), lastChangeLogID bigint, lastImportedChangeSetUUID varchar(255), lastExportedChangeSetUUID varchar(255), lastSyncDate timestamp with time zone, replicantType integer NOT NULL DEFAULT '0', replicantName varchar(1024), statusCode integer NOT NULL DEFAULT '0', offlineCloneDate timestamp with time zone, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX DatabaseReplicant_deletionUserID_index ON DatabaseReplicant (deletionUserID);
CREATE INDEX DatabaseReplicant_deletionDate_index ON DatabaseReplicant (deletionDate);
CREATE INDEX DatabaseReplicant_deletionIdentifier_index ON DatabaseReplicant (deletionIdentifier);
CREATE SEQUENCE DatabaseReplicant_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY DatabaseReplicant._rowid;
ALTER TABLE DatabaseReplicant ALTER COLUMN _rowid SET DEFAULT nextval('DatabaseReplicant_nextPK');
CREATE TRIGGER DatabaseReplicant_timestamp_updating BEFORE INSERT OR UPDATE ON DatabaseReplicant FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE DatabaseUpdate (_timestamp timestamp with time zone, affectsPrincipalApplication integer NOT NULL DEFAULT '0', databaseConfigurationID bigint, _rowid bigint PRIMARY KEY NOT NULL, date timestamp with time zone, note varchar(1024), updateContents bytea, updateSequence integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX DatabaseUpdate_deletionUserID_index ON DatabaseUpdate (deletionUserID);
CREATE INDEX DatabaseUpdate_deletionDate_index ON DatabaseUpdate (deletionDate);
CREATE INDEX DatabaseUpdate_deletionIdentifier_index ON DatabaseUpdate (deletionIdentifier);
CREATE SEQUENCE DatabaseUpdate_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY DatabaseUpdate._rowid;
ALTER TABLE DatabaseUpdate ALTER COLUMN _rowid SET DEFAULT nextval('DatabaseUpdate_nextPK');
CREATE TRIGGER DatabaseUpdate_timestamp_updating BEFORE INSERT OR UPDATE ON DatabaseUpdate FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Delegate (_timestamp timestamp with time zone, createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, entityName varchar(1024), note varchar(4096), objectID bigint, requireNotif integer NOT NULL DEFAULT '0', userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Delegate_userID_index ON Delegate (userID);
CREATE INDEX Delegate_deletionUserID_index ON Delegate (deletionUserID);
CREATE INDEX Delegate_deletionDate_index ON Delegate (deletionDate);
CREATE INDEX Delegate_deletionIdentifier_index ON Delegate (deletionIdentifier);
CREATE SEQUENCE Delegate_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Delegate._rowid;
ALTER TABLE Delegate ALTER COLUMN _rowid SET DEFAULT nextval('Delegate_nextPK');
CREATE TRIGGER Delegate_timestamp_updating BEFORE INSERT OR UPDATE ON Delegate FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Department (_timestamp timestamp with time zone, createDate timestamp with time zone, defaultFaxID bigint, defaultGeoAddressID bigint, defaultPhoneID bigint, _rowid bigint PRIMARY KEY NOT NULL, departmentNameID bigint, ordering integer NOT NULL DEFAULT '0', organizationID bigint, regionTypeID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Department_defaultFaxID_index ON Department (defaultFaxID);
CREATE INDEX Department_defaultGeoAddressID_index ON Department (defaultGeoAddressID);
CREATE INDEX Department_defaultPhoneID_index ON Department (defaultPhoneID);
CREATE INDEX Department_organizationID_index ON Department (organizationID);
CREATE INDEX Department_regionTypeID_index ON Department (regionTypeID);
CREATE INDEX Department_deletionUserID_index ON Department (deletionUserID);
CREATE INDEX Department_deletionDate_index ON Department (deletionDate);
CREATE INDEX Department_deletionIdentifier_index ON Department (deletionIdentifier);
CREATE SEQUENCE Department_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Department._rowid;
ALTER TABLE Department ALTER COLUMN _rowid SET DEFAULT nextval('Department_nextPK');
CREATE TRIGGER Department_timestamp_updating BEFORE INSERT OR UPDATE ON Department FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE DepartmentName (_timestamp timestamp with time zone, createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, name varchar(256), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX DepartmentName_deletionUserID_index ON DepartmentName (deletionUserID);
CREATE INDEX DepartmentName_deletionDate_index ON DepartmentName (deletionDate);
CREATE INDEX DepartmentName_deletionIdentifier_index ON DepartmentName (deletionIdentifier);
CREATE SEQUENCE DepartmentName_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY DepartmentName._rowid;
ALTER TABLE DepartmentName ALTER COLUMN _rowid SET DEFAULT nextval('DepartmentName_nextPK');
CREATE TRIGGER DepartmentName_timestamp_updating BEFORE INSERT OR UPDATE ON DepartmentName FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE DisplayState (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, payload bytea, sourceListID bigint, sourceListID2 bigint, userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX DisplayState_userID_index ON DisplayState (userID);
CREATE INDEX DisplayState_deletionUserID_index ON DisplayState (deletionUserID);
CREATE INDEX DisplayState_deletionDate_index ON DisplayState (deletionDate);
CREATE INDEX DisplayState_deletionIdentifier_index ON DisplayState (deletionIdentifier);
CREATE SEQUENCE DisplayState_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY DisplayState._rowid;
ALTER TABLE DisplayState ALTER COLUMN _rowid SET DEFAULT nextval('DisplayState_nextPK');
CREATE TRIGGER DisplayState_timestamp_updating BEFORE INSERT OR UPDATE ON DisplayState FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ElectronicAddress (_timestamp timestamp with time zone, addressProviderCode integer NOT NULL DEFAULT '0', addressTypeCode integer NOT NULL DEFAULT '0', contactID bigint, createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, labelID bigint, modifyDate timestamp with time zone, note varchar(1024), ordering integer NOT NULL DEFAULT '0', organizationID bigint, palmPhoneIndex integer NOT NULL DEFAULT '0', typeCode integer NOT NULL DEFAULT '0', url varchar(4096), useWhenSend integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ElectronicAddress_contactID_index ON ElectronicAddress (contactID);
CREATE INDEX ElectronicAddress_labelID_index ON ElectronicAddress (labelID);
CREATE INDEX ElectronicAddress_organizationID_index ON ElectronicAddress (organizationID);
CREATE INDEX ElectronicAddress_deletionUserID_index ON ElectronicAddress (deletionUserID);
CREATE INDEX ElectronicAddress_deletionDate_index ON ElectronicAddress (deletionDate);
CREATE INDEX ElectronicAddress_deletionIdentifier_index ON ElectronicAddress (deletionIdentifier);
CREATE SEQUENCE ElectronicAddress_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ElectronicAddress._rowid;
ALTER TABLE ElectronicAddress ALTER COLUMN _rowid SET DEFAULT nextval('ElectronicAddress_nextPK');
CREATE TRIGGER ElectronicAddress_timestamp_updating BEFORE INSERT OR UPDATE ON ElectronicAddress FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE EmailMessageStatus (_timestamp timestamp with time zone, createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, inReplyToMessageID varchar(1024), messageID varchar(1024), modifyDate timestamp with time zone, noteID bigint, processedByUserID bigint, statusCode integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX EmailMessageStatus_noteID_index ON EmailMessageStatus (noteID);
CREATE INDEX EmailMessageStatus_processedByUserID_index ON EmailMessageStatus (processedByUserID);
CREATE INDEX EmailMessageStatus_deletionUserID_index ON EmailMessageStatus (deletionUserID);
CREATE INDEX EmailMessageStatus_deletionDate_index ON EmailMessageStatus (deletionDate);
CREATE INDEX EmailMessageStatus_deletionIdentifier_index ON EmailMessageStatus (deletionIdentifier);
CREATE SEQUENCE EmailMessageStatus_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY EmailMessageStatus._rowid;
ALTER TABLE EmailMessageStatus ALTER COLUMN _rowid SET DEFAULT nextval('EmailMessageStatus_nextPK');
CREATE TRIGGER EmailMessageStatus_timestamp_updating BEFORE INSERT OR UPDATE ON EmailMessageStatus FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE EnvelopeTemplate (_timestamp timestamp with time zone, createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, largeDataID bigint, modifyDate timestamp with time zone, name varchar(256), rootID bigint, type integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX EnvelopeTemplate_largeDataID_index ON EnvelopeTemplate (largeDataID);
CREATE INDEX EnvelopeTemplate_deletionUserID_index ON EnvelopeTemplate (deletionUserID);
CREATE INDEX EnvelopeTemplate_deletionDate_index ON EnvelopeTemplate (deletionDate);
CREATE INDEX EnvelopeTemplate_deletionIdentifier_index ON EnvelopeTemplate (deletionIdentifier);
CREATE SEQUENCE EnvelopeTemplate_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY EnvelopeTemplate._rowid;
ALTER TABLE EnvelopeTemplate ALTER COLUMN _rowid SET DEFAULT nextval('EnvelopeTemplate_nextPK');
CREATE TRIGGER EnvelopeTemplate_timestamp_updating BEFORE INSERT OR UPDATE ON EnvelopeTemplate FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Estimate (_timestamp timestamp with time zone, comment varchar(4096), createDate timestamp with time zone, dueDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, estimateNumber varchar(1024), estimatePDFID bigint, estimateURLRefID bigint, modifyDate timestamp with time zone, name varchar(1024), opportunityID bigint, sendToContactID bigint, sendToCustom varchar(1024), sendToOrgID bigint, sentDate timestamp with time zone, tax1 double precision, tax1Name varchar(1024), tax2 double precision, tax2Name varchar(1024), termsID bigint, useCompoundSecondaryTax integer NOT NULL DEFAULT '0', useTax1 integer NOT NULL DEFAULT '0', useTax2 integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Estimate_estimatePDFID_index ON Estimate (estimatePDFID);
CREATE INDEX Estimate_estimateURLRefID_index ON Estimate (estimateURLRefID);
CREATE INDEX Estimate_opportunityID_index ON Estimate (opportunityID);
CREATE INDEX Estimate_sendToContactID_index ON Estimate (sendToContactID);
CREATE INDEX Estimate_sendToOrgID_index ON Estimate (sendToOrgID);
CREATE INDEX Estimate_termsID_index ON Estimate (termsID);
CREATE INDEX Estimate_deletionUserID_index ON Estimate (deletionUserID);
CREATE INDEX Estimate_deletionDate_index ON Estimate (deletionDate);
CREATE INDEX Estimate_deletionIdentifier_index ON Estimate (deletionIdentifier);
CREATE SEQUENCE Estimate_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Estimate._rowid;
ALTER TABLE Estimate ALTER COLUMN _rowid SET DEFAULT nextval('Estimate_nextPK');
CREATE TRIGGER Estimate_timestamp_updating BEFORE INSERT OR UPDATE ON Estimate FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ExtraFieldsNames (_timestamp timestamp with time zone, extra1 varchar(64), extra10 varchar(64), extra11 varchar(64), extra12 varchar(64), extra2 varchar(64), extra3 varchar(64), extra4 varchar(64), extra5 varchar(64), extra6 varchar(64), extra7 varchar(64), extra8 varchar(64), extra9 varchar(64), extraDate1 varchar(64), extraDate2 varchar(64), extraDate3 varchar(64), extraDate4 varchar(64), _rowid bigint PRIMARY KEY NOT NULL, rootID bigint, typeString varchar(64), deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ExtraFieldsNames_deletionUserID_index ON ExtraFieldsNames (deletionUserID);
CREATE INDEX ExtraFieldsNames_deletionDate_index ON ExtraFieldsNames (deletionDate);
CREATE INDEX ExtraFieldsNames_deletionIdentifier_index ON ExtraFieldsNames (deletionIdentifier);
CREATE SEQUENCE ExtraFieldsNames_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ExtraFieldsNames._rowid;
ALTER TABLE ExtraFieldsNames ALTER COLUMN _rowid SET DEFAULT nextval('ExtraFieldsNames_nextPK');
CREATE TRIGGER ExtraFieldsNames_timestamp_updating BEFORE INSERT OR UPDATE ON ExtraFieldsNames FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE FieldOption (_timestamp timestamp with time zone, entityName varchar(32), _rowid bigint PRIMARY KEY NOT NULL, keyName varchar(64), optionValue varchar(256), deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX FieldOption_deletionUserID_index ON FieldOption (deletionUserID);
CREATE INDEX FieldOption_deletionDate_index ON FieldOption (deletionDate);
CREATE INDEX FieldOption_deletionIdentifier_index ON FieldOption (deletionIdentifier);
CREATE SEQUENCE FieldOption_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY FieldOption._rowid;
ALTER TABLE FieldOption ALTER COLUMN _rowid SET DEFAULT nextval('FieldOption_nextPK');
CREATE TRIGGER FieldOption_timestamp_updating BEFORE INSERT OR UPDATE ON FieldOption FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE FileStorage (_timestamp timestamp with time zone, createDate timestamp with time zone, extension varchar(1024), _rowid bigint PRIMARY KEY NOT NULL, filename varchar(1024), modifyDate timestamp with time zone, rawData bytea, userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX FileStorage_userID_index ON FileStorage (userID);
CREATE INDEX FileStorage_deletionUserID_index ON FileStorage (deletionUserID);
CREATE INDEX FileStorage_deletionDate_index ON FileStorage (deletionDate);
CREATE INDEX FileStorage_deletionIdentifier_index ON FileStorage (deletionIdentifier);
CREATE SEQUENCE FileStorage_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY FileStorage._rowid;
ALTER TABLE FileStorage ALTER COLUMN _rowid SET DEFAULT nextval('FileStorage_nextPK');
CREATE TRIGGER FileStorage_timestamp_updating BEFORE INSERT OR UPDATE ON FileStorage FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE FilterResource (_timestamp timestamp with time zone, assignedToID bigint, createDate timestamp with time zone, createdByID bigint, _rowid bigint PRIMARY KEY NOT NULL, modifyDate timestamp with time zone, name varchar(1023), resourceLargeDataID bigint, rootID bigint, typeString varchar(255), deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX FilterResource_resourceLargeDataID_index ON FilterResource (resourceLargeDataID);
CREATE INDEX FilterResource_deletionUserID_index ON FilterResource (deletionUserID);
CREATE INDEX FilterResource_deletionDate_index ON FilterResource (deletionDate);
CREATE INDEX FilterResource_deletionIdentifier_index ON FilterResource (deletionIdentifier);
CREATE SEQUENCE FilterResource_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY FilterResource._rowid;
ALTER TABLE FilterResource ALTER COLUMN _rowid SET DEFAULT nextval('FilterResource_nextPK');
CREATE TRIGGER FilterResource_timestamp_updating BEFORE INSERT OR UPDATE ON FilterResource FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE GeoAddress (_timestamp timestamp with time zone, city varchar(255), contactID bigint, country varchar(255), createDate timestamp with time zone, departmentID bigint, directions varchar(1024), _rowid bigint PRIMARY KEY NOT NULL, labelID bigint, modifyDate timestamp with time zone, note varchar(1024), ordering integer NOT NULL DEFAULT '0', organizationID bigint, ownerType integer NOT NULL DEFAULT '0', postalCode varchar(64), state varchar(64), street varchar(1024), typeCode integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX GeoAddress_contactID_index ON GeoAddress (contactID);
CREATE INDEX GeoAddress_labelID_index ON GeoAddress (labelID);
CREATE INDEX GeoAddress_organizationID_index ON GeoAddress (organizationID);
CREATE INDEX GeoAddress_deletionUserID_index ON GeoAddress (deletionUserID);
CREATE INDEX GeoAddress_deletionDate_index ON GeoAddress (deletionDate);
CREATE INDEX GeoAddress_deletionIdentifier_index ON GeoAddress (deletionIdentifier);
CREATE SEQUENCE GeoAddress_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY GeoAddress._rowid;
ALTER TABLE GeoAddress ALTER COLUMN _rowid SET DEFAULT nextval('GeoAddress_nextPK');
CREATE TRIGGER GeoAddress_timestamp_updating BEFORE INSERT OR UPDATE ON GeoAddress FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE DLGroup (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', assignedToID bigint, categoryID bigint, createDate timestamp with time zone, createdByID bigint, defaultNoteID bigint, endDate timestamp with time zone, extra1 varchar(255), extra10 varchar(255), extra11 varchar(255), extra12 varchar(255), extra2 varchar(255), extra3 varchar(255), extra4 varchar(255), extra5 varchar(255), extra6 varchar(255), extra7 varchar(255), extra8 varchar(255), extra9 varchar(255), extraDate1 timestamp with time zone, extraDate2 timestamp with time zone, extraDate3 timestamp with time zone, extraDate4 timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, isPrivate integer NOT NULL DEFAULT '0', level integer NOT NULL DEFAULT '0', message varchar(1024), modifyDate timestamp with time zone, name varchar(256), note varchar(1024), ordering integer NOT NULL DEFAULT '0', parentGroupID bigint, permissionMask integer NOT NULL DEFAULT '0', quickSearchID bigint, rootID bigint, sourceImportID varchar(128), startDate timestamp with time zone, teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), visibilityPresetID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX DLGroup_assignedToID_index ON DLGroup (assignedToID);
CREATE INDEX DLGroup_categoryID_index ON DLGroup (categoryID);
CREATE INDEX DLGroup_createdByID_index ON DLGroup (createdByID);
CREATE INDEX DLGroup_defaultNoteID_index ON DLGroup (defaultNoteID);
CREATE INDEX DLGroup_parentGroupID_index ON DLGroup (parentGroupID);
CREATE INDEX DLGroup_quickSearchID_index ON DLGroup (quickSearchID);
CREATE INDEX DLGroup_visibilityPresetID_index ON DLGroup (visibilityPresetID);
CREATE INDEX DLGroup_deletionUserID_index ON DLGroup (deletionUserID);
CREATE INDEX DLGroup_deletionDate_index ON DLGroup (deletionDate);
CREATE INDEX DLGroup_deletionIdentifier_index ON DLGroup (deletionIdentifier);
CREATE SEQUENCE DLGroup_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY DLGroup._rowid;
ALTER TABLE DLGroup ALTER COLUMN _rowid SET DEFAULT nextval('DLGroup_nextPK');
CREATE TRIGGER DLGroup_timestamp_updating BEFORE INSERT OR UPDATE ON DLGroup FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE GroupNoteJoin (_timestamp timestamp with time zone, groupID bigint NOT NULL, noteID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX GroupNoteJoin_groupID_index ON GroupNoteJoin (groupID);
CREATE INDEX GroupNoteJoin_noteID_index ON GroupNoteJoin (noteID);
CREATE INDEX GroupNoteJoin_deletionUserID_index ON GroupNoteJoin (deletionUserID);
CREATE INDEX GroupNoteJoin_deletionDate_index ON GroupNoteJoin (deletionDate);
CREATE INDEX GroupNoteJoin_deletionIdentifier_index ON GroupNoteJoin (deletionIdentifier);
CREATE SEQUENCE GroupNoteJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY GroupNoteJoin._rowid;
ALTER TABLE GroupNoteJoin ALTER COLUMN _rowid SET DEFAULT nextval('GroupNoteJoin_nextPK');
CREATE TRIGGER GroupNoteJoin_timestamp_updating BEFORE INSERT OR UPDATE ON GroupNoteJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE GroupOpportunityJoin (_timestamp timestamp with time zone, groupID bigint NOT NULL, opportunityID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX GroupOpportunityJoin_groupID_index ON GroupOpportunityJoin (groupID);
CREATE INDEX GroupOpportunityJoin_opportunityID_index ON GroupOpportunityJoin (opportunityID);
CREATE INDEX GroupOpportunityJoin_deletionUserID_index ON GroupOpportunityJoin (deletionUserID);
CREATE INDEX GroupOpportunityJoin_deletionDate_index ON GroupOpportunityJoin (deletionDate);
CREATE INDEX GroupOpportunityJoin_deletionIdentifier_index ON GroupOpportunityJoin (deletionIdentifier);
CREATE SEQUENCE GroupOpportunityJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY GroupOpportunityJoin._rowid;
ALTER TABLE GroupOpportunityJoin ALTER COLUMN _rowid SET DEFAULT nextval('GroupOpportunityJoin_nextPK');
CREATE TRIGGER GroupOpportunityJoin_timestamp_updating BEFORE INSERT OR UPDATE ON GroupOpportunityJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE GroupOrganizationJoin (_timestamp timestamp with time zone, groupID bigint NOT NULL, organizationID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX GroupOrganizationJoin_groupID_index ON GroupOrganizationJoin (groupID);
CREATE INDEX GroupOrganizationJoin_organizationID_index ON GroupOrganizationJoin (organizationID);
CREATE INDEX GroupOrganizationJoin_deletionUserID_index ON GroupOrganizationJoin (deletionUserID);
CREATE INDEX GroupOrganizationJoin_deletionDate_index ON GroupOrganizationJoin (deletionDate);
CREATE INDEX GroupOrganizationJoin_deletionIdentifier_index ON GroupOrganizationJoin (deletionIdentifier);
CREATE SEQUENCE GroupOrganizationJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY GroupOrganizationJoin._rowid;
ALTER TABLE GroupOrganizationJoin ALTER COLUMN _rowid SET DEFAULT nextval('GroupOrganizationJoin_nextPK');
CREATE TRIGGER GroupOrganizationJoin_timestamp_updating BEFORE INSERT OR UPDATE ON GroupOrganizationJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE GroupProjectJoin (_timestamp timestamp with time zone, groupID bigint NOT NULL, projectID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX GroupProjectJoin_groupID_index ON GroupProjectJoin (groupID);
CREATE INDEX GroupProjectJoin_projectID_index ON GroupProjectJoin (projectID);
CREATE INDEX GroupProjectJoin_deletionUserID_index ON GroupProjectJoin (deletionUserID);
CREATE INDEX GroupProjectJoin_deletionDate_index ON GroupProjectJoin (deletionDate);
CREATE INDEX GroupProjectJoin_deletionIdentifier_index ON GroupProjectJoin (deletionIdentifier);
CREATE SEQUENCE GroupProjectJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY GroupProjectJoin._rowid;
ALTER TABLE GroupProjectJoin ALTER COLUMN _rowid SET DEFAULT nextval('GroupProjectJoin_nextPK');
CREATE TRIGGER GroupProjectJoin_timestamp_updating BEFORE INSERT OR UPDATE ON GroupProjectJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE GroupTaskJoin (_timestamp timestamp with time zone, groupID bigint NOT NULL, taskID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX GroupTaskJoin_groupID_index ON GroupTaskJoin (groupID);
CREATE INDEX GroupTaskJoin_taskID_index ON GroupTaskJoin (taskID);
CREATE INDEX GroupTaskJoin_deletionUserID_index ON GroupTaskJoin (deletionUserID);
CREATE INDEX GroupTaskJoin_deletionDate_index ON GroupTaskJoin (deletionDate);
CREATE INDEX GroupTaskJoin_deletionIdentifier_index ON GroupTaskJoin (deletionIdentifier);
CREATE SEQUENCE GroupTaskJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY GroupTaskJoin._rowid;
ALTER TABLE GroupTaskJoin ALTER COLUMN _rowid SET DEFAULT nextval('GroupTaskJoin_nextPK');
CREATE TRIGGER GroupTaskJoin_timestamp_updating BEFORE INSERT OR UPDATE ON GroupTaskJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE GroupTimeblockJoin (_timestamp timestamp with time zone, groupID bigint NOT NULL, timeblockID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX GroupTimeblockJoin_groupID_index ON GroupTimeblockJoin (groupID);
CREATE INDEX GroupTimeblockJoin_timeblockID_index ON GroupTimeblockJoin (timeblockID);
CREATE INDEX GroupTimeblockJoin_deletionUserID_index ON GroupTimeblockJoin (deletionUserID);
CREATE INDEX GroupTimeblockJoin_deletionDate_index ON GroupTimeblockJoin (deletionDate);
CREATE INDEX GroupTimeblockJoin_deletionIdentifier_index ON GroupTimeblockJoin (deletionIdentifier);
CREATE SEQUENCE GroupTimeblockJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY GroupTimeblockJoin._rowid;
ALTER TABLE GroupTimeblockJoin ALTER COLUMN _rowid SET DEFAULT nextval('GroupTimeblockJoin_nextPK');
CREATE TRIGGER GroupTimeblockJoin_timestamp_updating BEFORE INSERT OR UPDATE ON GroupTimeblockJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE IndustryType (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, name varchar(256), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX IndustryType_deletionUserID_index ON IndustryType (deletionUserID);
CREATE INDEX IndustryType_deletionDate_index ON IndustryType (deletionDate);
CREATE INDEX IndustryType_deletionIdentifier_index ON IndustryType (deletionIdentifier);
CREATE SEQUENCE IndustryType_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY IndustryType._rowid;
ALTER TABLE IndustryType ALTER COLUMN _rowid SET DEFAULT nextval('IndustryType_nextPK');
CREATE TRIGGER IndustryType_timestamp_updating BEFORE INSERT OR UPDATE ON IndustryType FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Keyword (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, forContact integer NOT NULL DEFAULT '0', forOpportunity integer NOT NULL DEFAULT '0', forOrganization integer NOT NULL DEFAULT '0', forProject integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, name varchar(255), ordering integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Keyword_deletionUserID_index ON Keyword (deletionUserID);
CREATE INDEX Keyword_deletionDate_index ON Keyword (deletionDate);
CREATE INDEX Keyword_deletionIdentifier_index ON Keyword (deletionIdentifier);
CREATE SEQUENCE Keyword_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Keyword._rowid;
ALTER TABLE Keyword ALTER COLUMN _rowid SET DEFAULT nextval('Keyword_nextPK');
CREATE TRIGGER Keyword_timestamp_updating BEFORE INSERT OR UPDATE ON Keyword FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE KeywordOpportunityJoin (_timestamp timestamp with time zone, keywordID bigint NOT NULL, opportunityID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX KeywordOpportunityJoin_keywordID_index ON KeywordOpportunityJoin (keywordID);
CREATE INDEX KeywordOpportunityJoin_opportunityID_index ON KeywordOpportunityJoin (opportunityID);
CREATE INDEX KeywordOpportunityJoin_deletionUserID_index ON KeywordOpportunityJoin (deletionUserID);
CREATE INDEX KeywordOpportunityJoin_deletionDate_index ON KeywordOpportunityJoin (deletionDate);
CREATE INDEX KeywordOpportunityJoin_deletionIdentifier_index ON KeywordOpportunityJoin (deletionIdentifier);
CREATE SEQUENCE KeywordOpportunityJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY KeywordOpportunityJoin._rowid;
ALTER TABLE KeywordOpportunityJoin ALTER COLUMN _rowid SET DEFAULT nextval('KeywordOpportunityJoin_nextPK');
CREATE TRIGGER KeywordOpportunityJoin_timestamp_updating BEFORE INSERT OR UPDATE ON KeywordOpportunityJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE KeywordOrganizationJoin (_timestamp timestamp with time zone, keywordID bigint NOT NULL, organizationID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX KeywordOrganizationJoin_keywordID_index ON KeywordOrganizationJoin (keywordID);
CREATE INDEX KeywordOrganizationJoin_organizationID_index ON KeywordOrganizationJoin (organizationID);
CREATE INDEX KeywordOrganizationJoin_deletionUserID_index ON KeywordOrganizationJoin (deletionUserID);
CREATE INDEX KeywordOrganizationJoin_deletionDate_index ON KeywordOrganizationJoin (deletionDate);
CREATE INDEX KeywordOrganizationJoin_deletionIdentifier_index ON KeywordOrganizationJoin (deletionIdentifier);
CREATE SEQUENCE KeywordOrganizationJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY KeywordOrganizationJoin._rowid;
ALTER TABLE KeywordOrganizationJoin ALTER COLUMN _rowid SET DEFAULT nextval('KeywordOrganizationJoin_nextPK');
CREATE TRIGGER KeywordOrganizationJoin_timestamp_updating BEFORE INSERT OR UPDATE ON KeywordOrganizationJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE KeywordProjectJoin (_timestamp timestamp with time zone, keywordID bigint NOT NULL, projectID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX KeywordProjectJoin_keywordID_index ON KeywordProjectJoin (keywordID);
CREATE INDEX KeywordProjectJoin_projectID_index ON KeywordProjectJoin (projectID);
CREATE INDEX KeywordProjectJoin_deletionUserID_index ON KeywordProjectJoin (deletionUserID);
CREATE INDEX KeywordProjectJoin_deletionDate_index ON KeywordProjectJoin (deletionDate);
CREATE INDEX KeywordProjectJoin_deletionIdentifier_index ON KeywordProjectJoin (deletionIdentifier);
CREATE SEQUENCE KeywordProjectJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY KeywordProjectJoin._rowid;
ALTER TABLE KeywordProjectJoin ALTER COLUMN _rowid SET DEFAULT nextval('KeywordProjectJoin_nextPK');
CREATE TRIGGER KeywordProjectJoin_timestamp_updating BEFORE INSERT OR UPDATE ON KeywordProjectJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Label (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', isDeletable integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, name varchar(256), syncServicesCode integer NOT NULL DEFAULT '0', typeCode integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Label_deletionUserID_index ON Label (deletionUserID);
CREATE INDEX Label_deletionDate_index ON Label (deletionDate);
CREATE INDEX Label_deletionIdentifier_index ON Label (deletionIdentifier);
CREATE SEQUENCE Label_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Label._rowid;
ALTER TABLE Label ALTER COLUMN _rowid SET DEFAULT nextval('Label_nextPK');
CREATE TRIGGER Label_timestamp_updating BEFORE INSERT OR UPDATE ON Label FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE LabelTemplate (_timestamp timestamp with time zone, createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, largeDataID bigint, modifyDate timestamp with time zone, name varchar(256), rootID bigint, type integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX LabelTemplate_largeDataID_index ON LabelTemplate (largeDataID);
CREATE INDEX LabelTemplate_deletionUserID_index ON LabelTemplate (deletionUserID);
CREATE INDEX LabelTemplate_deletionDate_index ON LabelTemplate (deletionDate);
CREATE INDEX LabelTemplate_deletionIdentifier_index ON LabelTemplate (deletionIdentifier);
CREATE SEQUENCE LabelTemplate_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY LabelTemplate._rowid;
ALTER TABLE LabelTemplate ALTER COLUMN _rowid SET DEFAULT nextval('LabelTemplate_nextPK');
CREATE TRIGGER LabelTemplate_timestamp_updating BEFORE INSERT OR UPDATE ON LabelTemplate FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE LargeData (_timestamp timestamp with time zone, createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, rawData bytea, plainText text, isPlainText integer NOT NULL DEFAULT '0', storesPlainTextRepresentation integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX LargeData_deletionUserID_index ON LargeData (deletionUserID);
CREATE INDEX LargeData_deletionDate_index ON LargeData (deletionDate);
CREATE INDEX LargeData_deletionIdentifier_index ON LargeData (deletionIdentifier);
CREATE SEQUENCE LargeData_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY LargeData._rowid;
ALTER TABLE LargeData ALTER COLUMN _rowid SET DEFAULT nextval('LargeData_nextPK');
CREATE TRIGGER LargeData_timestamp_updating BEFORE INSERT OR UPDATE ON LargeData FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE LeadSource (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, details varchar(1024), endDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, name varchar(256), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', rootID bigint, startDate timestamp with time zone, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX LeadSource_deletionUserID_index ON LeadSource (deletionUserID);
CREATE INDEX LeadSource_deletionDate_index ON LeadSource (deletionDate);
CREATE INDEX LeadSource_deletionIdentifier_index ON LeadSource (deletionIdentifier);
CREATE SEQUENCE LeadSource_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY LeadSource._rowid;
ALTER TABLE LeadSource ALTER COLUMN _rowid SET DEFAULT nextval('LeadSource_nextPK');
CREATE TRIGGER LeadSource_timestamp_updating BEFORE INSERT OR UPDATE ON LeadSource FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE LineItem (_timestamp timestamp with time zone, accountNumber varchar(255), basePrice double precision, costOfGoods double precision, createDate timestamp with time zone, currencyCode varchar(1024), details varchar(1024), discount double precision, discountTypeCode integer NOT NULL DEFAULT '0', estimateID bigint, extra1 varchar(255), extra2 varchar(255), extra3 varchar(255), extra4 varchar(255), extra5 varchar(255), extraDate1 timestamp with time zone, idCode varchar(1024), largeDataID bigint, _rowid bigint PRIMARY KEY NOT NULL, markup double precision, markupTypeCode integer NOT NULL DEFAULT '0', modelCode varchar(1024), modifyDate timestamp with time zone, name varchar(1024), opportunityID bigint, productServiceID bigint, profit double precision, resourceLargeDataID bigint, sku varchar(1024), tax1 double precision, tax1Name varchar(1024), tax2 double precision, tax2Name varchar(1024), taxCode varchar(255), typeCode integer NOT NULL DEFAULT '0', units double precision, upc varchar(1024), useCompoundSecondaryTax integer NOT NULL DEFAULT '0', useTax1 integer NOT NULL DEFAULT '0', useTax2 integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX LineItem_estimateID_index ON LineItem (estimateID);
CREATE INDEX LineItem_largeDataID_index ON LineItem (largeDataID);
CREATE INDEX LineItem_opportunityID_index ON LineItem (opportunityID);
CREATE INDEX LineItem_productServiceID_index ON LineItem (productServiceID);
CREATE INDEX LineItem_resourceLargeDataID_index ON LineItem (resourceLargeDataID);
CREATE INDEX LineItem_deletionUserID_index ON LineItem (deletionUserID);
CREATE INDEX LineItem_deletionDate_index ON LineItem (deletionDate);
CREATE INDEX LineItem_deletionIdentifier_index ON LineItem (deletionIdentifier);
CREATE SEQUENCE LineItem_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY LineItem._rowid;
ALTER TABLE LineItem ALTER COLUMN _rowid SET DEFAULT nextval('LineItem_nextPK');
CREATE TRIGGER LineItem_timestamp_updating BEFORE INSERT OR UPDATE ON LineItem FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE MeetingHistory (_timestamp timestamp with time zone, createDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, note varchar(4096), timeblockID bigint, typeCode integer NOT NULL DEFAULT '0', userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX MeetingHistory_timeblockID_index ON MeetingHistory (timeblockID);
CREATE INDEX MeetingHistory_userID_index ON MeetingHistory (userID);
CREATE INDEX MeetingHistory_deletionUserID_index ON MeetingHistory (deletionUserID);
CREATE INDEX MeetingHistory_deletionDate_index ON MeetingHistory (deletionDate);
CREATE INDEX MeetingHistory_deletionIdentifier_index ON MeetingHistory (deletionIdentifier);
CREATE SEQUENCE MeetingHistory_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY MeetingHistory._rowid;
ALTER TABLE MeetingHistory ALTER COLUMN _rowid SET DEFAULT nextval('MeetingHistory_nextPK');
CREATE TRIGGER MeetingHistory_timestamp_updating BEFORE INSERT OR UPDATE ON MeetingHistory FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Note (_timestamp timestamp with time zone, assignedToID bigint, calendarID bigint, categoryID bigint, contactID bigint, convertedToOneFive integer NOT NULL DEFAULT '0', createDate timestamp with time zone, createdByID bigint, emailMessageStatusID bigint, groupID bigint, isDefaultForContact integer NOT NULL DEFAULT '0', isDefaultForGroup integer NOT NULL DEFAULT '0', isDefaultForOpportunity integer NOT NULL DEFAULT '0', isDefaultForOrganization integer NOT NULL DEFAULT '0', isDefaultForProject integer NOT NULL DEFAULT '0', isEmail integer NOT NULL DEFAULT '0', isSyncNote integer NOT NULL DEFAULT '0', largeDataID bigint, modifyDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, ordering integer NOT NULL DEFAULT '0', organizationID bigint, permissionMask integer NOT NULL DEFAULT '0', quickSearchID bigint, rootID bigint, sharedDataID bigint, sourceImportID varchar(128), teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), title varchar(1024), typeCode integer NOT NULL DEFAULT '0', visibilityPresetID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Note_assignedToID_index ON Note (assignedToID);
CREATE INDEX Note_calendarID_index ON Note (calendarID);
CREATE INDEX Note_categoryID_index ON Note (categoryID);
CREATE INDEX Note_createdByID_index ON Note (createdByID);
CREATE INDEX Note_emailMessageStatusID_index ON Note (emailMessageStatusID);
CREATE INDEX Note_largeDataID_index ON Note (largeDataID);
CREATE INDEX Note_quickSearchID_index ON Note (quickSearchID);
CREATE INDEX Note_visibilityPresetID_index ON Note (visibilityPresetID);
CREATE INDEX Note_deletionUserID_index ON Note (deletionUserID);
CREATE INDEX Note_deletionDate_index ON Note (deletionDate);
CREATE INDEX Note_deletionIdentifier_index ON Note (deletionIdentifier);
CREATE SEQUENCE Note_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Note._rowid;
ALTER TABLE Note ALTER COLUMN _rowid SET DEFAULT nextval('Note_nextPK');
CREATE TRIGGER Note_timestamp_updating BEFORE INSERT OR UPDATE ON Note FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE NoteOpportunityJoin (_timestamp timestamp with time zone, noteID bigint NOT NULL, opportunityID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX NoteOpportunityJoin_noteID_index ON NoteOpportunityJoin (noteID);
CREATE INDEX NoteOpportunityJoin_opportunityID_index ON NoteOpportunityJoin (opportunityID);
CREATE INDEX NoteOpportunityJoin_deletionUserID_index ON NoteOpportunityJoin (deletionUserID);
CREATE INDEX NoteOpportunityJoin_deletionDate_index ON NoteOpportunityJoin (deletionDate);
CREATE INDEX NoteOpportunityJoin_deletionIdentifier_index ON NoteOpportunityJoin (deletionIdentifier);
CREATE SEQUENCE NoteOpportunityJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY NoteOpportunityJoin._rowid;
ALTER TABLE NoteOpportunityJoin ALTER COLUMN _rowid SET DEFAULT nextval('NoteOpportunityJoin_nextPK');
CREATE TRIGGER NoteOpportunityJoin_timestamp_updating BEFORE INSERT OR UPDATE ON NoteOpportunityJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE NoteProjectJoin (_timestamp timestamp with time zone, noteID bigint NOT NULL, projectID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX NoteProjectJoin_noteID_index ON NoteProjectJoin (noteID);
CREATE INDEX NoteProjectJoin_projectID_index ON NoteProjectJoin (projectID);
CREATE INDEX NoteProjectJoin_deletionUserID_index ON NoteProjectJoin (deletionUserID);
CREATE INDEX NoteProjectJoin_deletionDate_index ON NoteProjectJoin (deletionDate);
CREATE INDEX NoteProjectJoin_deletionIdentifier_index ON NoteProjectJoin (deletionIdentifier);
CREATE SEQUENCE NoteProjectJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY NoteProjectJoin._rowid;
ALTER TABLE NoteProjectJoin ALTER COLUMN _rowid SET DEFAULT nextval('NoteProjectJoin_nextPK');
CREATE TRIGGER NoteProjectJoin_timestamp_updating BEFORE INSERT OR UPDATE ON NoteProjectJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Opportunity (_timestamp timestamp with time zone, assignedToID bigint, cachedTotalAmount money, categoryID bigint, completeDate timestamp with time zone, connectorLockDate timestamp with time zone, connectorLockIdentifier varchar(128), connectorLockUserID bigint, createDate timestamp with time zone, createdByID bigint, currentPipelineID bigint, currentPipelineStageHistoryID bigint, currentPipelineStageID bigint, defaultNoteID bigint, delegateChain varchar(4096), details varchar(1024), dueDate timestamp with time zone, extra1 varchar(255), extra10 varchar(255), extra11 varchar(255), extra12 varchar(255), extra2 varchar(255), extra3 varchar(255), extra4 varchar(255), extra5 varchar(255), extra6 varchar(255), extra7 varchar(255), extra8 varchar(255), extra9 varchar(255), extraDate1 timestamp with time zone, extraDate2 timestamp with time zone, extraDate3 timestamp with time zone, extraDate4 timestamp with time zone, goalID bigint, lastOpportunityStateType integer NOT NULL DEFAULT '0', level integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, name varchar(1024), _rowid bigint PRIMARY KEY NOT NULL, opportunityStageID bigint, opportunityStateReasonID bigint, opportunityStateType integer NOT NULL DEFAULT '0', opportunityTypeID bigint, ordering integer NOT NULL DEFAULT '0', permissionMask integer NOT NULL DEFAULT '0', probability integer NOT NULL DEFAULT '0', productServiceID bigint, quickSearchID bigint, rootID bigint, sourceImportID varchar(128), startDate timestamp with time zone, teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), termID bigint, unitPrice money, units integer NOT NULL DEFAULT '0', visibilityPresetID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Opportunity_assignedToID_index ON Opportunity (assignedToID);
CREATE INDEX Opportunity_categoryID_index ON Opportunity (categoryID);
CREATE INDEX Opportunity_connectorLockUserID_index ON Opportunity (connectorLockUserID);
CREATE INDEX Opportunity_createdByID_index ON Opportunity (createdByID);
CREATE INDEX Opportunity_currentPipelineID_index ON Opportunity (currentPipelineID);
CREATE INDEX Opportunity_currentPipelineStageHistoryID_index ON Opportunity (currentPipelineStageHistoryID);
CREATE INDEX Opportunity_currentPipelineStageID_index ON Opportunity (currentPipelineStageID);
CREATE INDEX Opportunity_defaultNoteID_index ON Opportunity (defaultNoteID);
CREATE INDEX Opportunity_opportunityStageID_index ON Opportunity (opportunityStageID);
CREATE INDEX Opportunity_opportunityStateReasonID_index ON Opportunity (opportunityStateReasonID);
CREATE INDEX Opportunity_opportunityTypeID_index ON Opportunity (opportunityTypeID);
CREATE INDEX Opportunity_productServiceID_index ON Opportunity (productServiceID);
CREATE INDEX Opportunity_quickSearchID_index ON Opportunity (quickSearchID);
CREATE INDEX Opportunity_termID_index ON Opportunity (termID);
CREATE INDEX Opportunity_visibilityPresetID_index ON Opportunity (visibilityPresetID);
CREATE INDEX Opportunity_deletionUserID_index ON Opportunity (deletionUserID);
CREATE INDEX Opportunity_deletionDate_index ON Opportunity (deletionDate);
CREATE INDEX Opportunity_deletionIdentifier_index ON Opportunity (deletionIdentifier);
CREATE SEQUENCE Opportunity_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Opportunity._rowid;
ALTER TABLE Opportunity ALTER COLUMN _rowid SET DEFAULT nextval('Opportunity_nextPK');
CREATE TRIGGER Opportunity_timestamp_updating BEFORE INSERT OR UPDATE ON Opportunity FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OpportunityStage (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, details varchar(1024), encodedColor varchar(1024), name varchar(256), _rowid bigint PRIMARY KEY NOT NULL, ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OpportunityStage_deletionUserID_index ON OpportunityStage (deletionUserID);
CREATE INDEX OpportunityStage_deletionDate_index ON OpportunityStage (deletionDate);
CREATE INDEX OpportunityStage_deletionIdentifier_index ON OpportunityStage (deletionIdentifier);
CREATE SEQUENCE OpportunityStage_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OpportunityStage._rowid;
ALTER TABLE OpportunityStage ALTER COLUMN _rowid SET DEFAULT nextval('OpportunityStage_nextPK');
CREATE TRIGGER OpportunityStage_timestamp_updating BEFORE INSERT OR UPDATE ON OpportunityStage FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OpportunityStateReason (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, details varchar(1024), name varchar(256), _rowid bigint PRIMARY KEY NOT NULL, opportunityStateType integer NOT NULL DEFAULT '0', ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OpportunityStateReason_deletionUserID_index ON OpportunityStateReason (deletionUserID);
CREATE INDEX OpportunityStateReason_deletionDate_index ON OpportunityStateReason (deletionDate);
CREATE INDEX OpportunityStateReason_deletionIdentifier_index ON OpportunityStateReason (deletionIdentifier);
CREATE SEQUENCE OpportunityStateReason_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OpportunityStateReason._rowid;
ALTER TABLE OpportunityStateReason ALTER COLUMN _rowid SET DEFAULT nextval('OpportunityStateReason_nextPK');
CREATE TRIGGER OpportunityStateReason_timestamp_updating BEFORE INSERT OR UPDATE ON OpportunityStateReason FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OpportunityTaskJoin (_timestamp timestamp with time zone, opportunityID bigint NOT NULL, taskID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OpportunityTaskJoin_opportunityID_index ON OpportunityTaskJoin (opportunityID);
CREATE INDEX OpportunityTaskJoin_taskID_index ON OpportunityTaskJoin (taskID);
CREATE INDEX OpportunityTaskJoin_deletionUserID_index ON OpportunityTaskJoin (deletionUserID);
CREATE INDEX OpportunityTaskJoin_deletionDate_index ON OpportunityTaskJoin (deletionDate);
CREATE INDEX OpportunityTaskJoin_deletionIdentifier_index ON OpportunityTaskJoin (deletionIdentifier);
CREATE SEQUENCE OpportunityTaskJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OpportunityTaskJoin._rowid;
ALTER TABLE OpportunityTaskJoin ALTER COLUMN _rowid SET DEFAULT nextval('OpportunityTaskJoin_nextPK');
CREATE TRIGGER OpportunityTaskJoin_timestamp_updating BEFORE INSERT OR UPDATE ON OpportunityTaskJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OpportunityTimeblockJoin (_timestamp timestamp with time zone, opportunityID bigint NOT NULL, timeblockID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OpportunityTimeblockJoin_opportunityID_index ON OpportunityTimeblockJoin (opportunityID);
CREATE INDEX OpportunityTimeblockJoin_timeblockID_index ON OpportunityTimeblockJoin (timeblockID);
CREATE INDEX OpportunityTimeblockJoin_deletionUserID_index ON OpportunityTimeblockJoin (deletionUserID);
CREATE INDEX OpportunityTimeblockJoin_deletionDate_index ON OpportunityTimeblockJoin (deletionDate);
CREATE INDEX OpportunityTimeblockJoin_deletionIdentifier_index ON OpportunityTimeblockJoin (deletionIdentifier);
CREATE SEQUENCE OpportunityTimeblockJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OpportunityTimeblockJoin._rowid;
ALTER TABLE OpportunityTimeblockJoin ALTER COLUMN _rowid SET DEFAULT nextval('OpportunityTimeblockJoin_nextPK');
CREATE TRIGGER OpportunityTimeblockJoin_timestamp_updating BEFORE INSERT OR UPDATE ON OpportunityTimeblockJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OpportunityType (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, name varchar(256), _rowid bigint PRIMARY KEY NOT NULL, ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OpportunityType_deletionUserID_index ON OpportunityType (deletionUserID);
CREATE INDEX OpportunityType_deletionDate_index ON OpportunityType (deletionDate);
CREATE INDEX OpportunityType_deletionIdentifier_index ON OpportunityType (deletionIdentifier);
CREATE SEQUENCE OpportunityType_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OpportunityType._rowid;
ALTER TABLE OpportunityType ALTER COLUMN _rowid SET DEFAULT nextval('OpportunityType_nextPK');
CREATE TRIGGER OpportunityType_timestamp_updating BEFORE INSERT OR UPDATE ON OpportunityType FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Organization (_timestamp timestamp with time zone, assignedToID bigint, categoryID bigint, createDate timestamp with time zone, createdByID bigint, defaultElectronicAddressID bigint, defaultGeoAddressID bigint, defaultNoteID bigint, defaultPhoneID bigint, defaultSecondPhoneID bigint, detailsID integer, extra1 varchar(255), extra10 varchar(255), extra11 varchar(255), extra12 varchar(255), extra2 varchar(255), extra3 varchar(255), extra4 varchar(255), extra5 varchar(255), extra6 varchar(255), extra7 varchar(255), extra8 varchar(255), extra9 varchar(255), extraDate1 timestamp with time zone, extraDate2 timestamp with time zone, extraDate3 timestamp with time zone, extraDate4 timestamp with time zone, flagged integer NOT NULL DEFAULT '0', imageDataID bigint, industryTypeID bigint, level integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, name varchar(256), numberOfEmployees integer NOT NULL DEFAULT '0', ordering integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, organizationTypeID bigint, permissionMask integer NOT NULL DEFAULT '0', quickSearchID bigint, regionTypeID bigint, rootID bigint, sicCode varchar(32), sourceImportID varchar(128), tagline varchar(1024), teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), tickerSymbol varchar(64), visibilityPresetID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Organization_assignedToID_index ON Organization (assignedToID);
CREATE INDEX Organization_categoryID_index ON Organization (categoryID);
CREATE INDEX Organization_createdByID_index ON Organization (createdByID);
CREATE INDEX Organization_defaultElectronicAddressID_index ON Organization (defaultElectronicAddressID);
CREATE INDEX Organization_defaultGeoAddressID_index ON Organization (defaultGeoAddressID);
CREATE INDEX Organization_defaultNoteID_index ON Organization (defaultNoteID);
CREATE INDEX Organization_defaultPhoneID_index ON Organization (defaultPhoneID);
CREATE INDEX Organization_defaultSecondPhoneID_index ON Organization (defaultSecondPhoneID);
CREATE INDEX Organization_detailsID_index ON Organization (detailsID);
CREATE INDEX Organization_imageDataID_index ON Organization (imageDataID);
CREATE INDEX Organization_industryTypeID_index ON Organization (industryTypeID);
CREATE INDEX Organization_organizationTypeID_index ON Organization (organizationTypeID);
CREATE INDEX Organization_quickSearchID_index ON Organization (quickSearchID);
CREATE INDEX Organization_regionTypeID_index ON Organization (regionTypeID);
CREATE INDEX Organization_visibilityPresetID_index ON Organization (visibilityPresetID);
CREATE INDEX Organization_deletionUserID_index ON Organization (deletionUserID);
CREATE INDEX Organization_deletionDate_index ON Organization (deletionDate);
CREATE INDEX Organization_deletionIdentifier_index ON Organization (deletionIdentifier);
CREATE SEQUENCE Organization_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Organization._rowid;
ALTER TABLE Organization ALTER COLUMN _rowid SET DEFAULT nextval('Organization_nextPK');
CREATE TRIGGER Organization_timestamp_updating BEFORE INSERT OR UPDATE ON Organization FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OrganizationNoteJoin (_timestamp timestamp with time zone, noteID bigint NOT NULL, organizationID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OrganizationNoteJoin_noteID_index ON OrganizationNoteJoin (noteID);
CREATE INDEX OrganizationNoteJoin_organizationID_index ON OrganizationNoteJoin (organizationID);
CREATE INDEX OrganizationNoteJoin_deletionUserID_index ON OrganizationNoteJoin (deletionUserID);
CREATE INDEX OrganizationNoteJoin_deletionDate_index ON OrganizationNoteJoin (deletionDate);
CREATE INDEX OrganizationNoteJoin_deletionIdentifier_index ON OrganizationNoteJoin (deletionIdentifier);
CREATE SEQUENCE OrganizationNoteJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OrganizationNoteJoin._rowid;
ALTER TABLE OrganizationNoteJoin ALTER COLUMN _rowid SET DEFAULT nextval('OrganizationNoteJoin_nextPK');
CREATE TRIGGER OrganizationNoteJoin_timestamp_updating BEFORE INSERT OR UPDATE ON OrganizationNoteJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OrganizationTaskJoin (_timestamp timestamp with time zone, organizationID bigint NOT NULL, taskID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OrganizationTaskJoin_organizationID_index ON OrganizationTaskJoin (organizationID);
CREATE INDEX OrganizationTaskJoin_taskID_index ON OrganizationTaskJoin (taskID);
CREATE INDEX OrganizationTaskJoin_deletionUserID_index ON OrganizationTaskJoin (deletionUserID);
CREATE INDEX OrganizationTaskJoin_deletionDate_index ON OrganizationTaskJoin (deletionDate);
CREATE INDEX OrganizationTaskJoin_deletionIdentifier_index ON OrganizationTaskJoin (deletionIdentifier);
CREATE SEQUENCE OrganizationTaskJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OrganizationTaskJoin._rowid;
ALTER TABLE OrganizationTaskJoin ALTER COLUMN _rowid SET DEFAULT nextval('OrganizationTaskJoin_nextPK');
CREATE TRIGGER OrganizationTaskJoin_timestamp_updating BEFORE INSERT OR UPDATE ON OrganizationTaskJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OrganizationTimeblockJoin (_timestamp timestamp with time zone, organizationID bigint NOT NULL, timeblockID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OrganizationTimeblockJoin_organizationID_index ON OrganizationTimeblockJoin (organizationID);
CREATE INDEX OrganizationTimeblockJoin_timeblockID_index ON OrganizationTimeblockJoin (timeblockID);
CREATE INDEX OrganizationTimeblockJoin_deletionUserID_index ON OrganizationTimeblockJoin (deletionUserID);
CREATE INDEX OrganizationTimeblockJoin_deletionDate_index ON OrganizationTimeblockJoin (deletionDate);
CREATE INDEX OrganizationTimeblockJoin_deletionIdentifier_index ON OrganizationTimeblockJoin (deletionIdentifier);
CREATE SEQUENCE OrganizationTimeblockJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OrganizationTimeblockJoin._rowid;
ALTER TABLE OrganizationTimeblockJoin ALTER COLUMN _rowid SET DEFAULT nextval('OrganizationTimeblockJoin_nextPK');
CREATE TRIGGER OrganizationTimeblockJoin_timestamp_updating BEFORE INSERT OR UPDATE ON OrganizationTimeblockJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OrganizationType (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, name varchar(256), ordering integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, privateTypeCode integer NOT NULL DEFAULT '0', rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OrganizationType_deletionUserID_index ON OrganizationType (deletionUserID);
CREATE INDEX OrganizationType_deletionDate_index ON OrganizationType (deletionDate);
CREATE INDEX OrganizationType_deletionIdentifier_index ON OrganizationType (deletionIdentifier);
CREATE SEQUENCE OrganizationType_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OrganizationType._rowid;
ALTER TABLE OrganizationType ALTER COLUMN _rowid SET DEFAULT nextval('OrganizationType_nextPK');
CREATE TRIGGER OrganizationType_timestamp_updating BEFORE INSERT OR UPDATE ON OrganizationType FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE PalmSyncMap (_timestamp timestamp with time zone, contactID bigint, isArchived integer NOT NULL DEFAULT '0', noteID bigint, organizationID bigint, palmFlag integer NOT NULL DEFAULT '0', palmID bigint, _rowid bigint PRIMARY KEY NOT NULL, taskID bigint, timeblockID bigint, typeCode integer NOT NULL DEFAULT '0', userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX PalmSyncMap_contactID_index ON PalmSyncMap (contactID);
CREATE INDEX PalmSyncMap_noteID_index ON PalmSyncMap (noteID);
CREATE INDEX PalmSyncMap_organizationID_index ON PalmSyncMap (organizationID);
CREATE INDEX PalmSyncMap_taskID_index ON PalmSyncMap (taskID);
CREATE INDEX PalmSyncMap_timeblockID_index ON PalmSyncMap (timeblockID);
CREATE INDEX PalmSyncMap_userID_index ON PalmSyncMap (userID);
CREATE INDEX PalmSyncMap_deletionUserID_index ON PalmSyncMap (deletionUserID);
CREATE INDEX PalmSyncMap_deletionDate_index ON PalmSyncMap (deletionDate);
CREATE INDEX PalmSyncMap_deletionIdentifier_index ON PalmSyncMap (deletionIdentifier);
CREATE SEQUENCE PalmSyncMap_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY PalmSyncMap._rowid;
ALTER TABLE PalmSyncMap ALTER COLUMN _rowid SET DEFAULT nextval('PalmSyncMap_nextPK');
CREATE TRIGGER PalmSyncMap_timestamp_updating BEFORE INSERT OR UPDATE ON PalmSyncMap FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Phone (_timestamp timestamp with time zone, areaCode varchar(64), contactID bigint, countryCode varchar(64), createDate timestamp with time zone, extension varchar(32), labelID bigint, modifyDate timestamp with time zone, note varchar(1024), ordering integer NOT NULL DEFAULT '0', organizationID bigint, palmPhoneIndex integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, phoneNumber varchar(128), typeCode integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Phone_contactID_index ON Phone (contactID);
CREATE INDEX Phone_labelID_index ON Phone (labelID);
CREATE INDEX Phone_organizationID_index ON Phone (organizationID);
CREATE INDEX Phone_deletionUserID_index ON Phone (deletionUserID);
CREATE INDEX Phone_deletionDate_index ON Phone (deletionDate);
CREATE INDEX Phone_deletionIdentifier_index ON Phone (deletionIdentifier);
CREATE SEQUENCE Phone_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Phone._rowid;
ALTER TABLE Phone ALTER COLUMN _rowid SET DEFAULT nextval('Phone_nextPK');
CREATE TRIGGER Phone_timestamp_updating BEFORE INSERT OR UPDATE ON Phone FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Pipeline (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, forOpportunity integer NOT NULL DEFAULT '0', forProject integer NOT NULL DEFAULT '0', lowerThreshold integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, name varchar(4096), note varchar(4096), _rowid bigint PRIMARY KEY NOT NULL, upperThreshold integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Pipeline_deletionUserID_index ON Pipeline (deletionUserID);
CREATE INDEX Pipeline_deletionDate_index ON Pipeline (deletionDate);
CREATE INDEX Pipeline_deletionIdentifier_index ON Pipeline (deletionIdentifier);
CREATE SEQUENCE Pipeline_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Pipeline._rowid;
ALTER TABLE Pipeline ALTER COLUMN _rowid SET DEFAULT nextval('Pipeline_nextPK');
CREATE TRIGGER Pipeline_timestamp_updating BEFORE INSERT OR UPDATE ON Pipeline FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE PipelineStage (_timestamp timestamp with time zone, createDate timestamp with time zone, lowerThreshold integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, name varchar(4096), note varchar(4096), ordering integer NOT NULL DEFAULT '0', pipelineID bigint, _rowid bigint PRIMARY KEY NOT NULL, upperThreshold integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX PipelineStage_pipelineID_index ON PipelineStage (pipelineID);
CREATE INDEX PipelineStage_deletionUserID_index ON PipelineStage (deletionUserID);
CREATE INDEX PipelineStage_deletionDate_index ON PipelineStage (deletionDate);
CREATE INDEX PipelineStage_deletionIdentifier_index ON PipelineStage (deletionIdentifier);
CREATE SEQUENCE PipelineStage_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY PipelineStage._rowid;
ALTER TABLE PipelineStage ALTER COLUMN _rowid SET DEFAULT nextval('PipelineStage_nextPK');
CREATE TRIGGER PipelineStage_timestamp_updating BEFORE INSERT OR UPDATE ON PipelineStage FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE PipelineStageHistory (_timestamp timestamp with time zone, createDate timestamp with time zone, createdByID bigint, createdByUsername varchar(4096), endDate timestamp with time zone, modifyDate timestamp with time zone, note varchar(4096), opportunityID bigint, pipelineID bigint, pipelineName varchar(4096), _rowid bigint PRIMARY KEY NOT NULL, pipelineStageID bigint, previousPipelineID bigint, previousPipelineName varchar(4096), previousPipelineStageID bigint, previousStageName varchar(4096), projectID bigint, stageName varchar(4096), startDate timestamp with time zone, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX PipelineStageHistory_createdByID_index ON PipelineStageHistory (createdByID);
CREATE INDEX PipelineStageHistory_opportunityID_index ON PipelineStageHistory (opportunityID);
CREATE INDEX PipelineStageHistory_pipelineID_index ON PipelineStageHistory (pipelineID);
CREATE INDEX PipelineStageHistory_previousPipelineID_index ON PipelineStageHistory (previousPipelineID);
CREATE INDEX PipelineStageHistory_previousPipelineStageID_index ON PipelineStageHistory (previousPipelineStageID);
CREATE INDEX PipelineStageHistory_projectID_index ON PipelineStageHistory (projectID);
CREATE INDEX PipelineStageHistory_deletionUserID_index ON PipelineStageHistory (deletionUserID);
CREATE INDEX PipelineStageHistory_deletionDate_index ON PipelineStageHistory (deletionDate);
CREATE INDEX PipelineStageHistory_deletionIdentifier_index ON PipelineStageHistory (deletionIdentifier);
CREATE SEQUENCE PipelineStageHistory_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY PipelineStageHistory._rowid;
ALTER TABLE PipelineStageHistory ALTER COLUMN _rowid SET DEFAULT nextval('PipelineStageHistory_nextPK');
CREATE TRIGGER PipelineStageHistory_timestamp_updating BEFORE INSERT OR UPDATE ON PipelineStageHistory FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Privilege (_timestamp timestamp with time zone, code integer NOT NULL DEFAULT '0', createDate timestamp with time zone, detail varchar(256), name varchar(256), ordering integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Privilege_deletionUserID_index ON Privilege (deletionUserID);
CREATE INDEX Privilege_deletionDate_index ON Privilege (deletionDate);
CREATE INDEX Privilege_deletionIdentifier_index ON Privilege (deletionIdentifier);
CREATE SEQUENCE Privilege_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Privilege._rowid;
ALTER TABLE Privilege ALTER COLUMN _rowid SET DEFAULT nextval('Privilege_nextPK');
CREATE TRIGGER Privilege_timestamp_updating BEFORE INSERT OR UPDATE ON Privilege FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE PrivilegeUserJoin (_timestamp timestamp with time zone, privilegeID bigint NOT NULL, userID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX PrivilegeUserJoin_privilegeID_index ON PrivilegeUserJoin (privilegeID);
CREATE INDEX PrivilegeUserJoin_userID_index ON PrivilegeUserJoin (userID);
CREATE INDEX PrivilegeUserJoin_deletionUserID_index ON PrivilegeUserJoin (deletionUserID);
CREATE INDEX PrivilegeUserJoin_deletionDate_index ON PrivilegeUserJoin (deletionDate);
CREATE INDEX PrivilegeUserJoin_deletionIdentifier_index ON PrivilegeUserJoin (deletionIdentifier);
CREATE SEQUENCE PrivilegeUserJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY PrivilegeUserJoin._rowid;
ALTER TABLE PrivilegeUserJoin ALTER COLUMN _rowid SET DEFAULT nextval('PrivilegeUserJoin_nextPK');
CREATE TRIGGER PrivilegeUserJoin_timestamp_updating BEFORE INSERT OR UPDATE ON PrivilegeUserJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ProductService (_timestamp timestamp with time zone, accountNumber varchar(255), active integer NOT NULL DEFAULT '0', basePrice double precision, costOfGoods double precision, createDate timestamp with time zone, currencyCode varchar(1024), details varchar(1024), discount double precision, discountTypeCode integer NOT NULL DEFAULT '0', extra1 varchar(255), extra2 varchar(255), extra3 varchar(255), extra4 varchar(255), extra5 varchar(255), extraDate1 timestamp with time zone, idCode varchar(1024), largeDataID bigint, markup double precision, markupTypeCode integer NOT NULL DEFAULT '0', modelCode varchar(1024), modifyDate timestamp with time zone, name varchar(256), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, profit double precision, resourceLargeDataID bigint, rootID bigint, sku varchar(1024), taxCode varchar(255), typeCode integer NOT NULL DEFAULT '0', units double precision, upc varchar(1024), useCompoundSecondaryTax integer NOT NULL DEFAULT '0', useTax1 integer NOT NULL DEFAULT '0', useTax2 integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ProductService_largeDataID_index ON ProductService (largeDataID);
CREATE INDEX ProductService_resourceLargeDataID_index ON ProductService (resourceLargeDataID);
CREATE INDEX ProductService_deletionUserID_index ON ProductService (deletionUserID);
CREATE INDEX ProductService_deletionDate_index ON ProductService (deletionDate);
CREATE INDEX ProductService_deletionIdentifier_index ON ProductService (deletionIdentifier);
CREATE SEQUENCE ProductService_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ProductService._rowid;
ALTER TABLE ProductService ALTER COLUMN _rowid SET DEFAULT nextval('ProductService_nextPK');
CREATE TRIGGER ProductService_timestamp_updating BEFORE INSERT OR UPDATE ON ProductService FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Project (_timestamp timestamp with time zone, assignedToID bigint, cachedTotalEstimatedTime bigint, categoryID bigint, completeDate timestamp with time zone, createDate timestamp with time zone, createdByID bigint, currentPipelineID bigint, currentPipelineStageHistoryID bigint, currentPipelineStageID bigint, defaultNoteID bigint, delegateChain varchar(4096), details varchar(1024), dueDate timestamp with time zone, estimatedTime bigint, extra1 varchar(255), extra10 varchar(255), extra11 varchar(255), extra12 varchar(255), extra2 varchar(255), extra3 varchar(255), extra4 varchar(255), extra5 varchar(255), extra6 varchar(255), extra7 varchar(255), extra8 varchar(255), extra9 varchar(255), extraDate1 timestamp with time zone, extraDate2 timestamp with time zone, extraDate3 timestamp with time zone, extraDate4 timestamp with time zone, goalID bigint, lastStatusCode integer NOT NULL DEFAULT '0', level integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, name varchar(4096), opportunityID bigint, ordering integer NOT NULL DEFAULT '0', percentComplete integer NOT NULL DEFAULT '0', permissionMask integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, projectStageID bigint, quickSearchID bigint, rootID bigint, sourceImportID varchar(128), startDate timestamp with time zone, statusCode integer NOT NULL DEFAULT '0', teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), visibilityPresetID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Project_assignedToID_index ON Project (assignedToID);
CREATE INDEX Project_categoryID_index ON Project (categoryID);
CREATE INDEX Project_createdByID_index ON Project (createdByID);
CREATE INDEX Project_currentPipelineID_index ON Project (currentPipelineID);
CREATE INDEX Project_currentPipelineStageHistoryID_index ON Project (currentPipelineStageHistoryID);
CREATE INDEX Project_currentPipelineStageID_index ON Project (currentPipelineStageID);
CREATE INDEX Project_defaultNoteID_index ON Project (defaultNoteID);
CREATE INDEX Project_opportunityID_index ON Project (opportunityID);
CREATE INDEX Project_projectStageID_index ON Project (projectStageID);
CREATE INDEX Project_quickSearchID_index ON Project (quickSearchID);
CREATE INDEX Project_visibilityPresetID_index ON Project (visibilityPresetID);
CREATE INDEX Project_deletionUserID_index ON Project (deletionUserID);
CREATE INDEX Project_deletionDate_index ON Project (deletionDate);
CREATE INDEX Project_deletionIdentifier_index ON Project (deletionIdentifier);
CREATE SEQUENCE Project_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Project._rowid;
ALTER TABLE Project ALTER COLUMN _rowid SET DEFAULT nextval('Project_nextPK');
CREATE TRIGGER Project_timestamp_updating BEFORE INSERT OR UPDATE ON Project FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ProjectStage (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, details varchar(1024), encodedColor varchar(1024), name varchar(256), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ProjectStage_deletionUserID_index ON ProjectStage (deletionUserID);
CREATE INDEX ProjectStage_deletionDate_index ON ProjectStage (deletionDate);
CREATE INDEX ProjectStage_deletionIdentifier_index ON ProjectStage (deletionIdentifier);
CREATE SEQUENCE ProjectStage_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ProjectStage._rowid;
ALTER TABLE ProjectStage ALTER COLUMN _rowid SET DEFAULT nextval('ProjectStage_nextPK');
CREATE TRIGGER ProjectStage_timestamp_updating BEFORE INSERT OR UPDATE ON ProjectStage FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ProjectTaskJoin (_timestamp timestamp with time zone, projectID bigint NOT NULL, taskID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ProjectTaskJoin_projectID_index ON ProjectTaskJoin (projectID);
CREATE INDEX ProjectTaskJoin_taskID_index ON ProjectTaskJoin (taskID);
CREATE INDEX ProjectTaskJoin_deletionUserID_index ON ProjectTaskJoin (deletionUserID);
CREATE INDEX ProjectTaskJoin_deletionDate_index ON ProjectTaskJoin (deletionDate);
CREATE INDEX ProjectTaskJoin_deletionIdentifier_index ON ProjectTaskJoin (deletionIdentifier);
CREATE SEQUENCE ProjectTaskJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ProjectTaskJoin._rowid;
ALTER TABLE ProjectTaskJoin ALTER COLUMN _rowid SET DEFAULT nextval('ProjectTaskJoin_nextPK');
CREATE TRIGGER ProjectTaskJoin_timestamp_updating BEFORE INSERT OR UPDATE ON ProjectTaskJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ProjectTimeblockJoin (_timestamp timestamp with time zone, projectID bigint NOT NULL, timeblockID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ProjectTimeblockJoin_projectID_index ON ProjectTimeblockJoin (projectID);
CREATE INDEX ProjectTimeblockJoin_timeblockID_index ON ProjectTimeblockJoin (timeblockID);
CREATE INDEX ProjectTimeblockJoin_deletionUserID_index ON ProjectTimeblockJoin (deletionUserID);
CREATE INDEX ProjectTimeblockJoin_deletionDate_index ON ProjectTimeblockJoin (deletionDate);
CREATE INDEX ProjectTimeblockJoin_deletionIdentifier_index ON ProjectTimeblockJoin (deletionIdentifier);
CREATE SEQUENCE ProjectTimeblockJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ProjectTimeblockJoin._rowid;
ALTER TABLE ProjectTimeblockJoin ALTER COLUMN _rowid SET DEFAULT nextval('ProjectTimeblockJoin_nextPK');
CREATE TRIGGER ProjectTimeblockJoin_timestamp_updating BEFORE INSERT OR UPDATE ON ProjectTimeblockJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE QuickSearch (_timestamp timestamp with time zone, assignedToID bigint, contactID bigint, groupID bigint, metaString varchar(4096), noteID bigint, opportunityID bigint, organizationID bigint, projectID bigint, _rowid bigint PRIMARY KEY NOT NULL, taskID bigint, teamsPermissionCode varchar(4096), timeblockID bigint, visibilityPresetID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX QuickSearch_contactID_index ON QuickSearch (contactID);
CREATE INDEX QuickSearch_groupID_index ON QuickSearch (groupID);
CREATE INDEX QuickSearch_noteID_index ON QuickSearch (noteID);
CREATE INDEX QuickSearch_opportunityID_index ON QuickSearch (opportunityID);
CREATE INDEX QuickSearch_organizationID_index ON QuickSearch (organizationID);
CREATE INDEX QuickSearch_projectID_index ON QuickSearch (projectID);
CREATE INDEX QuickSearch_taskID_index ON QuickSearch (taskID);
CREATE INDEX QuickSearch_timeblockID_index ON QuickSearch (timeblockID);
CREATE INDEX QuickSearch_visibilityPresetID_index ON QuickSearch (visibilityPresetID);
CREATE INDEX QuickSearch_deletionUserID_index ON QuickSearch (deletionUserID);
CREATE INDEX QuickSearch_deletionDate_index ON QuickSearch (deletionDate);
CREATE INDEX QuickSearch_deletionIdentifier_index ON QuickSearch (deletionIdentifier);
CREATE SEQUENCE QuickSearch_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY QuickSearch._rowid;
ALTER TABLE QuickSearch ALTER COLUMN _rowid SET DEFAULT nextval('QuickSearch_nextPK');
CREATE TRIGGER QuickSearch_timestamp_updating BEFORE INSERT OR UPDATE ON QuickSearch FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE RegionType (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, name varchar(256), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX RegionType_deletionUserID_index ON RegionType (deletionUserID);
CREATE INDEX RegionType_deletionDate_index ON RegionType (deletionDate);
CREATE INDEX RegionType_deletionIdentifier_index ON RegionType (deletionIdentifier);
CREATE SEQUENCE RegionType_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY RegionType._rowid;
ALTER TABLE RegionType ALTER COLUMN _rowid SET DEFAULT nextval('RegionType_nextPK');
CREATE TRIGGER RegionType_timestamp_updating BEFORE INSERT OR UPDATE ON RegionType FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Relationship (_timestamp timestamp with time zone, createDate timestamp with time zone, destinationContactID bigint, destinationOrgID bigint, details varchar(128), note varchar(1024), ordering integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, relationshipTypeID bigint, sourceContactID bigint, sourceOrgID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Relationship_destinationContactID_index ON Relationship (destinationContactID);
CREATE INDEX Relationship_destinationOrgID_index ON Relationship (destinationOrgID);
CREATE INDEX Relationship_relationshipTypeID_index ON Relationship (relationshipTypeID);
CREATE INDEX Relationship_sourceContactID_index ON Relationship (sourceContactID);
CREATE INDEX Relationship_sourceOrgID_index ON Relationship (sourceOrgID);
CREATE INDEX Relationship_deletionUserID_index ON Relationship (deletionUserID);
CREATE INDEX Relationship_deletionDate_index ON Relationship (deletionDate);
CREATE INDEX Relationship_deletionIdentifier_index ON Relationship (deletionIdentifier);
CREATE SEQUENCE Relationship_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Relationship._rowid;
ALTER TABLE Relationship ALTER COLUMN _rowid SET DEFAULT nextval('Relationship_nextPK');
CREATE TRIGGER Relationship_timestamp_updating BEFORE INSERT OR UPDATE ON Relationship FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE RelationshipType (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, forContact integer NOT NULL DEFAULT '0', forOrganization integer NOT NULL DEFAULT '0', name varchar(256), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, restrictForwardToOne integer NOT NULL DEFAULT '0', restrictReverseToOne integer NOT NULL DEFAULT '0', reverseName varchar(255), rootID bigint, shortName varchar(255), shortReverseName varchar(255), deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX RelationshipType_deletionUserID_index ON RelationshipType (deletionUserID);
CREATE INDEX RelationshipType_deletionDate_index ON RelationshipType (deletionDate);
CREATE INDEX RelationshipType_deletionIdentifier_index ON RelationshipType (deletionIdentifier);
CREATE SEQUENCE RelationshipType_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY RelationshipType._rowid;
ALTER TABLE RelationshipType ALTER COLUMN _rowid SET DEFAULT nextval('RelationshipType_nextPK');
CREATE TRIGGER RelationshipType_timestamp_updating BEFORE INSERT OR UPDATE ON RelationshipType FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OldReminder (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', archived integer NOT NULL DEFAULT '0', calendarID bigint, createDate timestamp with time zone, displayAlertMessage varchar(1023), fireDatetime timestamp with time zone, firedDatetime timestamp with time zone, hasAudioAlert integer NOT NULL DEFAULT '0', hasDisplayAlert integer NOT NULL DEFAULT '0', hasMailAlert integer NOT NULL DEFAULT '0', measure integer NOT NULL DEFAULT '0', message varchar(1024), modifyDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, reminderSettings bytea, rootID bigint, taskID bigint, timeblockID bigint, unit integer NOT NULL DEFAULT '0', userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OldReminder_taskID_index ON OldReminder (taskID);
CREATE INDEX OldReminder_timeblockID_index ON OldReminder (timeblockID);
CREATE INDEX OldReminder_userID_index ON OldReminder (userID);
CREATE INDEX OldReminder_deletionUserID_index ON OldReminder (deletionUserID);
CREATE INDEX OldReminder_deletionDate_index ON OldReminder (deletionDate);
CREATE INDEX OldReminder_deletionIdentifier_index ON OldReminder (deletionIdentifier);
CREATE SEQUENCE OldReminder_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OldReminder._rowid;
ALTER TABLE OldReminder ALTER COLUMN _rowid SET DEFAULT nextval('OldReminder_nextPK');
CREATE TRIGGER OldReminder_timestamp_updating BEFORE INSERT OR UPDATE ON OldReminder FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE RepeatEntry (_timestamp timestamp with time zone, daysOfYear varchar(2048), _rowid bigint PRIMARY KEY NOT NULL, timeblockID bigint, year integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX RepeatEntry_timeblockID_index ON RepeatEntry (timeblockID);
CREATE INDEX RepeatEntry_deletionUserID_index ON RepeatEntry (deletionUserID);
CREATE INDEX RepeatEntry_deletionDate_index ON RepeatEntry (deletionDate);
CREATE INDEX RepeatEntry_deletionIdentifier_index ON RepeatEntry (deletionIdentifier);
CREATE SEQUENCE RepeatEntry_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY RepeatEntry._rowid;
ALTER TABLE RepeatEntry ALTER COLUMN _rowid SET DEFAULT nextval('RepeatEntry_nextPK');
CREATE TRIGGER RepeatEntry_timestamp_updating BEFORE INSERT OR UPDATE ON RepeatEntry FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE RepeatExceptionEntry (_timestamp timestamp with time zone, daysOfYear varchar(2048), _rowid bigint PRIMARY KEY NOT NULL, timeblockID bigint, year integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX RepeatExceptionEntry_timeblockID_index ON RepeatExceptionEntry (timeblockID);
CREATE INDEX RepeatExceptionEntry_deletionUserID_index ON RepeatExceptionEntry (deletionUserID);
CREATE INDEX RepeatExceptionEntry_deletionDate_index ON RepeatExceptionEntry (deletionDate);
CREATE INDEX RepeatExceptionEntry_deletionIdentifier_index ON RepeatExceptionEntry (deletionIdentifier);
CREATE SEQUENCE RepeatExceptionEntry_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY RepeatExceptionEntry._rowid;
ALTER TABLE RepeatExceptionEntry ALTER COLUMN _rowid SET DEFAULT nextval('RepeatExceptionEntry_nextPK');
CREATE TRIGGER RepeatExceptionEntry_timestamp_updating BEFORE INSERT OR UPDATE ON RepeatExceptionEntry FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE RepeatRule (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', archived integer NOT NULL DEFAULT '0', calendarID bigint, createDate timestamp with time zone, daysOfWeek integer NOT NULL DEFAULT '0', frequency integer NOT NULL DEFAULT '0', interval integer NOT NULL DEFAULT '0', monthDay integer NOT NULL DEFAULT '0', repeatCount integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, shortcutRuleCode integer NOT NULL DEFAULT '0', startDate timestamp with time zone, taskID bigint, timeblockID bigint, until timestamp with time zone, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX RepeatRule_taskID_index ON RepeatRule (taskID);
CREATE INDEX RepeatRule_timeblockID_index ON RepeatRule (timeblockID);
CREATE INDEX RepeatRule_deletionUserID_index ON RepeatRule (deletionUserID);
CREATE INDEX RepeatRule_deletionDate_index ON RepeatRule (deletionDate);
CREATE INDEX RepeatRule_deletionIdentifier_index ON RepeatRule (deletionIdentifier);
CREATE SEQUENCE RepeatRule_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY RepeatRule._rowid;
ALTER TABLE RepeatRule ALTER COLUMN _rowid SET DEFAULT nextval('RepeatRule_nextPK');
CREATE TRIGGER RepeatRule_timestamp_updating BEFORE INSERT OR UPDATE ON RepeatRule FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ReportSchedule (_timestamp timestamp with time zone, createDate timestamp with time zone, lastRunDate timestamp with time zone, lastRunStatusCode integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, nextRunDate timestamp with time zone, optionsData bytea, _rowid bigint PRIMARY KEY NOT NULL, reportTemplateID bigint, userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ReportSchedule_reportTemplateID_index ON ReportSchedule (reportTemplateID);
CREATE INDEX ReportSchedule_userID_index ON ReportSchedule (userID);
CREATE INDEX ReportSchedule_deletionUserID_index ON ReportSchedule (deletionUserID);
CREATE INDEX ReportSchedule_deletionDate_index ON ReportSchedule (deletionDate);
CREATE INDEX ReportSchedule_deletionIdentifier_index ON ReportSchedule (deletionIdentifier);
CREATE SEQUENCE ReportSchedule_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ReportSchedule._rowid;
ALTER TABLE ReportSchedule ALTER COLUMN _rowid SET DEFAULT nextval('ReportSchedule_nextPK');
CREATE TRIGGER ReportSchedule_timestamp_updating BEFORE INSERT OR UPDATE ON ReportSchedule FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ReportTemplate (_timestamp timestamp with time zone, isDayliteDeliveryLicenseExempt integer NOT NULL DEFAULT '0', behaviors varchar(512), createDate timestamp with time zone, entityName varchar(128), isActiveCode integer NOT NULL DEFAULT '0', isDayliteDeliveryReport integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, name varchar(128), _rowid bigint PRIMARY KEY NOT NULL, teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), templateData bytea, visibilityPresetID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ReportTemplate_visibilityPresetID_index ON ReportTemplate (visibilityPresetID);
CREATE INDEX ReportTemplate_deletionUserID_index ON ReportTemplate (deletionUserID);
CREATE INDEX ReportTemplate_deletionDate_index ON ReportTemplate (deletionDate);
CREATE INDEX ReportTemplate_deletionIdentifier_index ON ReportTemplate (deletionIdentifier);
CREATE SEQUENCE ReportTemplate_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ReportTemplate._rowid;
ALTER TABLE ReportTemplate ALTER COLUMN _rowid SET DEFAULT nextval('ReportTemplate_nextPK');
CREATE TRIGGER ReportTemplate_timestamp_updating BEFORE INSERT OR UPDATE ON ReportTemplate FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Resource (_timestamp timestamp with time zone, createDate timestamp with time zone, details varchar(4096), encodeColor varchar(1024), isActive integer NOT NULL DEFAULT '0', location varchar(512), name varchar(256), _rowid bigint PRIMARY KEY NOT NULL, rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Resource_deletionUserID_index ON Resource (deletionUserID);
CREATE INDEX Resource_deletionDate_index ON Resource (deletionDate);
CREATE INDEX Resource_deletionIdentifier_index ON Resource (deletionIdentifier);
CREATE SEQUENCE Resource_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Resource._rowid;
ALTER TABLE Resource ALTER COLUMN _rowid SET DEFAULT nextval('Resource_nextPK');
CREATE TRIGGER Resource_timestamp_updating BEFORE INSERT OR UPDATE ON Resource FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ResourceLargeData (_timestamp timestamp with time zone, createDate timestamp with time zone, rawData bytea, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ResourceLargeData_deletionUserID_index ON ResourceLargeData (deletionUserID);
CREATE INDEX ResourceLargeData_deletionDate_index ON ResourceLargeData (deletionDate);
CREATE INDEX ResourceLargeData_deletionIdentifier_index ON ResourceLargeData (deletionIdentifier);
CREATE SEQUENCE ResourceLargeData_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ResourceLargeData._rowid;
ALTER TABLE ResourceLargeData ALTER COLUMN _rowid SET DEFAULT nextval('ResourceLargeData_nextPK');
CREATE TRIGGER ResourceLargeData_timestamp_updating BEFORE INSERT OR UPDATE ON ResourceLargeData FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE ResourceTimeblockJoin (_timestamp timestamp with time zone, resourceID bigint NOT NULL, timeblockID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX ResourceTimeblockJoin_resourceID_index ON ResourceTimeblockJoin (resourceID);
CREATE INDEX ResourceTimeblockJoin_timeblockID_index ON ResourceTimeblockJoin (timeblockID);
CREATE INDEX ResourceTimeblockJoin_deletionUserID_index ON ResourceTimeblockJoin (deletionUserID);
CREATE INDEX ResourceTimeblockJoin_deletionDate_index ON ResourceTimeblockJoin (deletionDate);
CREATE INDEX ResourceTimeblockJoin_deletionIdentifier_index ON ResourceTimeblockJoin (deletionIdentifier);
CREATE SEQUENCE ResourceTimeblockJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY ResourceTimeblockJoin._rowid;
ALTER TABLE ResourceTimeblockJoin ALTER COLUMN _rowid SET DEFAULT nextval('ResourceTimeblockJoin_nextPK');
CREATE TRIGGER ResourceTimeblockJoin_timestamp_updating BEFORE INSERT OR UPDATE ON ResourceTimeblockJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Role (_timestamp timestamp with time zone, contactID bigint, createDate timestamp with time zone, defaultForContact bigint, department varchar(255), name varchar(256), opportunityID bigint, ordering integer NOT NULL DEFAULT '0', organizationID bigint, projectID bigint, _rowid bigint PRIMARY KEY NOT NULL, roleTypeID bigint, userOpportunityID bigint, userProjectID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Role_contactID_index ON Role (contactID);
CREATE INDEX Role_opportunityID_index ON Role (opportunityID);
CREATE INDEX Role_organizationID_index ON Role (organizationID);
CREATE INDEX Role_projectID_index ON Role (projectID);
CREATE INDEX Role_roleTypeID_index ON Role (roleTypeID);
CREATE INDEX Role_deletionUserID_index ON Role (deletionUserID);
CREATE INDEX Role_deletionDate_index ON Role (deletionDate);
CREATE INDEX Role_deletionIdentifier_index ON Role (deletionIdentifier);
CREATE SEQUENCE Role_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Role._rowid;
ALTER TABLE Role ALTER COLUMN _rowid SET DEFAULT nextval('Role_nextPK');
CREATE TRIGGER Role_timestamp_updating BEFORE INSERT OR UPDATE ON Role FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE RoleType (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', appliesToTypeCode integer NOT NULL DEFAULT '0', createDate timestamp with time zone, defaultTypeCode integer NOT NULL DEFAULT '0', forContact integer NOT NULL DEFAULT '0', forOpportunity integer NOT NULL DEFAULT '0', forOrganization integer NOT NULL DEFAULT '0', forProject integer NOT NULL DEFAULT '0', name varchar(256), ordering integer NOT NULL DEFAULT '0', privateTypeCode integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, rootID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX RoleType_deletionUserID_index ON RoleType (deletionUserID);
CREATE INDEX RoleType_deletionDate_index ON RoleType (deletionDate);
CREATE INDEX RoleType_deletionIdentifier_index ON RoleType (deletionIdentifier);
CREATE SEQUENCE RoleType_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY RoleType._rowid;
ALTER TABLE RoleType ALTER COLUMN _rowid SET DEFAULT nextval('RoleType_nextPK');
CREATE TRIGGER RoleType_timestamp_updating BEFORE INSERT OR UPDATE ON RoleType FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Root (_timestamp timestamp with time zone, createDate timestamp with time zone, modifyDate timestamp with time zone, ownerID bigint, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Root_ownerID_index ON Root (ownerID);
CREATE INDEX Root_deletionUserID_index ON Root (deletionUserID);
CREATE INDEX Root_deletionDate_index ON Root (deletionDate);
CREATE INDEX Root_deletionIdentifier_index ON Root (deletionIdentifier);
CREATE SEQUENCE Root_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Root._rowid;
ALTER TABLE Root ALTER COLUMN _rowid SET DEFAULT nextval('Root_nextPK');
CREATE TRIGGER Root_timestamp_updating BEFORE INSERT OR UPDATE ON Root FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE SLDumbJoin (_timestamp timestamp with time zone, addedDate timestamp with time zone, destinationID bigint, destinationTypeCode bigint, _rowid bigint PRIMARY KEY NOT NULL, sourceListID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX SLDumbJoin_deletionUserID_index ON SLDumbJoin (deletionUserID);
CREATE INDEX SLDumbJoin_deletionDate_index ON SLDumbJoin (deletionDate);
CREATE INDEX SLDumbJoin_deletionIdentifier_index ON SLDumbJoin (deletionIdentifier);
CREATE SEQUENCE SLDumbJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY SLDumbJoin._rowid;
ALTER TABLE SLDumbJoin ALTER COLUMN _rowid SET DEFAULT nextval('SLDumbJoin_nextPK');
CREATE TRIGGER SLDumbJoin_timestamp_updating BEFORE INSERT OR UPDATE ON SLDumbJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE SLWatchJoin (_timestamp timestamp with time zone, eoID bigint, _rowid bigint PRIMARY KEY NOT NULL, sourceListHostID bigint, sourceListID bigint, stateCode bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX SLWatchJoin_deletionUserID_index ON SLWatchJoin (deletionUserID);
CREATE INDEX SLWatchJoin_deletionDate_index ON SLWatchJoin (deletionDate);
CREATE INDEX SLWatchJoin_deletionIdentifier_index ON SLWatchJoin (deletionIdentifier);
CREATE SEQUENCE SLWatchJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY SLWatchJoin._rowid;
ALTER TABLE SLWatchJoin ALTER COLUMN _rowid SET DEFAULT nextval('SLWatchJoin_nextPK');
CREATE TRIGGER SLWatchJoin_timestamp_updating BEFORE INSERT OR UPDATE ON SLWatchJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE SourceList (_timestamp timestamp with time zone, applicationTypeCode integer NOT NULL DEFAULT '0', assignedToID bigint, details varchar(1028), filterUIState bytea, forEntityName varchar(32), groupIdentifier varchar(64), isDefaultCode integer NOT NULL DEFAULT '0', isHiddenFlag integer NOT NULL DEFAULT '0', name varchar(32), orderCode integer NOT NULL DEFAULT '0', parentListID bigint, permissionMask integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), typeCode integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX SourceList_assignedToID_index ON SourceList (assignedToID);
CREATE INDEX SourceList_parentListID_index ON SourceList (parentListID);
CREATE INDEX SourceList_deletionUserID_index ON SourceList (deletionUserID);
CREATE INDEX SourceList_deletionDate_index ON SourceList (deletionDate);
CREATE INDEX SourceList_deletionIdentifier_index ON SourceList (deletionIdentifier);
CREATE SEQUENCE SourceList_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY SourceList._rowid;
ALTER TABLE SourceList ALTER COLUMN _rowid SET DEFAULT nextval('SourceList_nextPK');
CREATE TRIGGER SourceList_timestamp_updating BEFORE INSERT OR UPDATE ON SourceList FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE SyncEntityGroupConfig (_timestamp timestamp with time zone, activeFlag integer NOT NULL DEFAULT '0', entityGroupIdentifier varchar(128), lastSyncDate timestamp with time zone, settingsStorage bytea, _rowid bigint PRIMARY KEY NOT NULL, syncID varchar(128), userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX SyncEntityGroupConfig_userID_index ON SyncEntityGroupConfig (userID);
CREATE INDEX SyncEntityGroupConfig_deletionUserID_index ON SyncEntityGroupConfig (deletionUserID);
CREATE INDEX SyncEntityGroupConfig_deletionDate_index ON SyncEntityGroupConfig (deletionDate);
CREATE INDEX SyncEntityGroupConfig_deletionIdentifier_index ON SyncEntityGroupConfig (deletionIdentifier);
CREATE SEQUENCE SyncEntityGroupConfig_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY SyncEntityGroupConfig._rowid;
ALTER TABLE SyncEntityGroupConfig ALTER COLUMN _rowid SET DEFAULT nextval('SyncEntityGroupConfig_nextPK');
CREATE TRIGGER SyncEntityGroupConfig_timestamp_updating BEFORE INSERT OR UPDATE ON SyncEntityGroupConfig FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE SyncEntityMemory (_timestamp timestamp with time zone, entityCode integer NOT NULL DEFAULT '0', lastSyncDate timestamp with time zone, lastSyncModeCode integer NOT NULL DEFAULT '0', nextSyncModeCode integer NOT NULL DEFAULT '0', syncEntityGroupConfigID bigint, _rowid bigint PRIMARY KEY NOT NULL, syncID varchar(128), userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX SyncEntityMemory_syncEntityGroupConfigID_index ON SyncEntityMemory (syncEntityGroupConfigID);
CREATE INDEX SyncEntityMemory_userID_index ON SyncEntityMemory (userID);
CREATE INDEX SyncEntityMemory_deletionUserID_index ON SyncEntityMemory (deletionUserID);
CREATE INDEX SyncEntityMemory_deletionDate_index ON SyncEntityMemory (deletionDate);
CREATE INDEX SyncEntityMemory_deletionIdentifier_index ON SyncEntityMemory (deletionIdentifier);
CREATE SEQUENCE SyncEntityMemory_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY SyncEntityMemory._rowid;
ALTER TABLE SyncEntityMemory ALTER COLUMN _rowid SET DEFAULT nextval('SyncEntityMemory_nextPK');
CREATE TRIGGER SyncEntityMemory_timestamp_updating BEFORE INSERT OR UPDATE ON SyncEntityMemory FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE SyncMap (_timestamp timestamp with time zone, categoryID bigint, contactID bigint, eAddressID bigint, entityCode integer NOT NULL DEFAULT '0', gAddressID bigint, lastSyncDate timestamp with time zone, objectID bigint, organizationID bigint, phoneID bigint, reminderID bigint, syncID varchar(128), syncIdentifier varchar, _rowid bigint PRIMARY KEY NOT NULL, taskID bigint, timeblockID bigint, userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX SyncMap_categoryID_index ON SyncMap (categoryID);
CREATE INDEX SyncMap_contactID_index ON SyncMap (contactID);
CREATE INDEX SyncMap_eAddressID_index ON SyncMap (eAddressID);
CREATE INDEX SyncMap_gAddressID_index ON SyncMap (gAddressID);
CREATE INDEX SyncMap_organizationID_index ON SyncMap (organizationID);
CREATE INDEX SyncMap_phoneID_index ON SyncMap (phoneID);
CREATE INDEX SyncMap_reminderID_index ON SyncMap (reminderID);
CREATE INDEX SyncMap_taskID_index ON SyncMap (taskID);
CREATE INDEX SyncMap_timeblockID_index ON SyncMap (timeblockID);
CREATE INDEX SyncMap_userID_index ON SyncMap (userID);
CREATE INDEX SyncMap_deletionUserID_index ON SyncMap (deletionUserID);
CREATE INDEX SyncMap_deletionDate_index ON SyncMap (deletionDate);
CREATE INDEX SyncMap_deletionIdentifier_index ON SyncMap (deletionIdentifier);
CREATE SEQUENCE SyncMap_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY SyncMap._rowid;
ALTER TABLE SyncMap ALTER COLUMN _rowid SET DEFAULT nextval('SyncMap_nextPK');
CREATE TRIGGER SyncMap_timestamp_updating BEFORE INSERT OR UPDATE ON SyncMap FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Task (_timestamp timestamp with time zone, assignedToID bigint, billedDate timestamp with time zone, billingRateID bigint, cachedTotalEstimatedTime bigint, calendarID bigint, categoryID bigint, completeDate timestamp with time zone, createDate timestamp with time zone, createdByID bigint, delegateChain varchar(4096), details varchar(4096), dueDate timestamp with time zone, estimatedTime bigint, indexNumber integer NOT NULL DEFAULT '0', isMatchCandidate integer NOT NULL DEFAULT '0', isPrivate integer NOT NULL DEFAULT '0', lastStatusCode integer NOT NULL DEFAULT '0', location varchar(256), modifyDate timestamp with time zone, ordering integer NOT NULL DEFAULT '0', parentTaskID bigint, percentComplete integer NOT NULL DEFAULT '0', permissionMask integer NOT NULL DEFAULT '0', priority integer NOT NULL DEFAULT '0', projectID bigint, quickSearchID bigint, reminderID bigint, resultCode integer NOT NULL DEFAULT '0', rootTaskID bigint, sourceImportID varchar(128), startDate timestamp with time zone, statusCode integer NOT NULL DEFAULT '0', subtaskCount integer NOT NULL DEFAULT '0', _rowid bigint PRIMARY KEY NOT NULL, teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), title varchar(1024), typeCode integer NOT NULL DEFAULT '0', url varchar(4096), visibilityPresetID bigint, someday integer NOT NULL DEFAULT '0', inboxUsers varchar, syncServicesStatusCode integer NOT NULL DEFAULT '0', deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Task_assignedToID_index ON Task (assignedToID);
CREATE INDEX Task_billingRateID_index ON Task (billingRateID);
CREATE INDEX Task_calendarID_index ON Task (calendarID);
CREATE INDEX Task_categoryID_index ON Task (categoryID);
CREATE INDEX Task_createdByID_index ON Task (createdByID);
CREATE INDEX Task_parentTaskID_index ON Task (parentTaskID);
CREATE INDEX Task_quickSearchID_index ON Task (quickSearchID);
CREATE INDEX Task_reminderID_index ON Task (reminderID);
CREATE INDEX Task_visibilityPresetID_index ON Task (visibilityPresetID);
CREATE INDEX Task_someday_index ON Task (someday);
CREATE INDEX Task_inboxUsers_index ON Task (inboxUsers);
CREATE INDEX Task_deletionUserID_index ON Task (deletionUserID);
CREATE INDEX Task_deletionDate_index ON Task (deletionDate);
CREATE INDEX Task_deletionIdentifier_index ON Task (deletionIdentifier);
CREATE SEQUENCE Task_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Task._rowid;
ALTER TABLE Task ALTER COLUMN _rowid SET DEFAULT nextval('Task_nextPK');
CREATE TRIGGER Task_timestamp_updating BEFORE INSERT OR UPDATE ON Task FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Team (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', createDate timestamp with time zone, isAdminTeam integer NOT NULL DEFAULT '0', isAllTeam integer NOT NULL DEFAULT '0', isSuperTeam integer NOT NULL DEFAULT '0', isUserPrivateTeam integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, name varchar, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Team_deletionUserID_index ON Team (deletionUserID);
CREATE INDEX Team_deletionDate_index ON Team (deletionDate);
CREATE INDEX Team_deletionIdentifier_index ON Team (deletionIdentifier);
CREATE SEQUENCE Team_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Team._rowid;
ALTER TABLE Team ALTER COLUMN _rowid SET DEFAULT nextval('Team_nextPK');
CREATE TRIGGER Team_timestamp_updating BEFORE INSERT OR UPDATE ON Team FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE TeamUserJoin (_timestamp timestamp with time zone, teamID bigint NOT NULL, userID bigint NOT NULL, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX TeamUserJoin_teamID_index ON TeamUserJoin (teamID);
CREATE INDEX TeamUserJoin_userID_index ON TeamUserJoin (userID);
CREATE INDEX TeamUserJoin_deletionUserID_index ON TeamUserJoin (deletionUserID);
CREATE INDEX TeamUserJoin_deletionDate_index ON TeamUserJoin (deletionDate);
CREATE INDEX TeamUserJoin_deletionIdentifier_index ON TeamUserJoin (deletionIdentifier);
CREATE SEQUENCE TeamUserJoin_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY TeamUserJoin._rowid;
ALTER TABLE TeamUserJoin ALTER COLUMN _rowid SET DEFAULT nextval('TeamUserJoin_nextPK');
CREATE TRIGGER TeamUserJoin_timestamp_updating BEFORE INSERT OR UPDATE ON TeamUserJoin FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Timeblock (_timestamp timestamp with time zone, acceptedUserInviteeSet varchar(4096), archived integer NOT NULL DEFAULT '0', billedDate timestamp with time zone, billingRateID bigint, busyCode integer NOT NULL DEFAULT '0', calendarID bigint, categoryID bigint, createDate timestamp with time zone, createdByID bigint, delegateChain varchar(4096), details varchar(4096), endDate timestamp with time zone, isMatchCandidate integer NOT NULL DEFAULT '0', isPrivate integer NOT NULL DEFAULT '0', location varchar(256), meetingMinutesLargeDataID bigint, modifyDate timestamp with time zone, ownerID bigint, parentTimeblockID bigint, pendingUserInviteeSet varchar(4096), permissionMask integer NOT NULL DEFAULT '0', projectID bigint, quickSearchID bigint, rejectedUserInviteeSet varchar(4096), reminderFireDate timestamp with time zone, reminderID bigint, reminderUnitType integer NOT NULL DEFAULT '0', reminderUnits integer NOT NULL DEFAULT '0', repeatByDays varchar(256), repeatByMonthDays varchar(256), repeatByMonths varchar(256), repeatByNthDay integer NOT NULL DEFAULT '0', repeatCount integer NOT NULL DEFAULT '0', repeatEndDate timestamp with time zone, repeatFrequency integer NOT NULL DEFAULT '0', repeatInterval integer NOT NULL DEFAULT '0', repeatModifyDate timestamp with time zone, repeatOriginalDate timestamp with time zone, repeatRuleID bigint, sharedDataID bigint, sourceImportID varchar(128), startDate timestamp with time zone, statusCode integer NOT NULL DEFAULT '0', subject varchar(1024), teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), timeZoneName varchar(128), _rowid bigint PRIMARY KEY NOT NULL, typeCode integer NOT NULL DEFAULT '0', url varchar(4096), userInviteeSet varchar(4096), visibilityPresetID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Timeblock_billingRateID_index ON Timeblock (billingRateID);
CREATE INDEX Timeblock_calendarID_index ON Timeblock (calendarID);
CREATE INDEX Timeblock_categoryID_index ON Timeblock (categoryID);
CREATE INDEX Timeblock_createdByID_index ON Timeblock (createdByID);
CREATE INDEX Timeblock_meetingMinutesLargeDataID_index ON Timeblock (meetingMinutesLargeDataID);
CREATE INDEX Timeblock_ownerID_index ON Timeblock (ownerID);
CREATE INDEX Timeblock_parentTimeblockID_index ON Timeblock (parentTimeblockID);
CREATE INDEX Timeblock_quickSearchID_index ON Timeblock (quickSearchID);
CREATE INDEX Timeblock_reminderID_index ON Timeblock (reminderID);
CREATE INDEX Timeblock_repeatRuleID_index ON Timeblock (repeatRuleID);
CREATE INDEX Timeblock_visibilityPresetID_index ON Timeblock (visibilityPresetID);
CREATE INDEX Timeblock_deletionUserID_index ON Timeblock (deletionUserID);
CREATE INDEX Timeblock_deletionDate_index ON Timeblock (deletionDate);
CREATE INDEX Timeblock_deletionIdentifier_index ON Timeblock (deletionIdentifier);
CREATE SEQUENCE Timeblock_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Timeblock._rowid;
ALTER TABLE Timeblock ALTER COLUMN _rowid SET DEFAULT nextval('Timeblock_nextPK');
CREATE TRIGGER Timeblock_timestamp_updating BEFORE INSERT OR UPDATE ON Timeblock FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE TimeblockException (_timestamp timestamp with time zone, dateTime timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, timeblockID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX TimeblockException_timeblockID_index ON TimeblockException (timeblockID);
CREATE INDEX TimeblockException_deletionUserID_index ON TimeblockException (deletionUserID);
CREATE INDEX TimeblockException_deletionDate_index ON TimeblockException (deletionDate);
CREATE INDEX TimeblockException_deletionIdentifier_index ON TimeblockException (deletionIdentifier);
CREATE SEQUENCE TimeblockException_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY TimeblockException._rowid;
ALTER TABLE TimeblockException ALTER COLUMN _rowid SET DEFAULT nextval('TimeblockException_nextPK');
CREATE TRIGGER TimeblockException_timestamp_updating BEFORE INSERT OR UPDATE ON TimeblockException FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE URLReference (_timestamp timestamp with time zone, contactID bigint, createDate timestamp with time zone, groupID bigint, modifyDate timestamp with time zone, name varchar(255), note varchar(1024), opportunityID bigint, ordering integer NOT NULL DEFAULT '0', organizationID bigint, projectID bigint, shareDataID bigint, typeCode integer NOT NULL DEFAULT '0', url varchar(4096), _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX URLReference_contactID_index ON URLReference (contactID);
CREATE INDEX URLReference_groupID_index ON URLReference (groupID);
CREATE INDEX URLReference_opportunityID_index ON URLReference (opportunityID);
CREATE INDEX URLReference_organizationID_index ON URLReference (organizationID);
CREATE INDEX URLReference_projectID_index ON URLReference (projectID);
CREATE INDEX URLReference_deletionUserID_index ON URLReference (deletionUserID);
CREATE INDEX URLReference_deletionDate_index ON URLReference (deletionDate);
CREATE INDEX URLReference_deletionIdentifier_index ON URLReference (deletionIdentifier);
CREATE SEQUENCE URLReference_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY URLReference._rowid;
ALTER TABLE URLReference ALTER COLUMN _rowid SET DEFAULT nextval('URLReference_nextPK');
CREATE TRIGGER URLReference_timestamp_updating BEFORE INSERT OR UPDATE ON URLReference FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE DLUser (_timestamp timestamp with time zone, abSyncGroupID bigint, active integer NOT NULL DEFAULT '0', assistantID bigint, contactID bigint, createDate timestamp with time zone, details varchar(1024), encodeColor varchar(1024), modifyDate timestamp with time zone, ordering integer NOT NULL DEFAULT '0', password varchar(128), perm1 integer NOT NULL DEFAULT '0', perm10 integer NOT NULL DEFAULT '0', perm11 integer NOT NULL DEFAULT '0', perm12 integer NOT NULL DEFAULT '0', perm13 integer NOT NULL DEFAULT '0', perm14 integer NOT NULL DEFAULT '0', perm15 integer NOT NULL DEFAULT '0', perm16 integer NOT NULL DEFAULT '0', perm17 integer NOT NULL DEFAULT '0', perm18 integer NOT NULL DEFAULT '0', perm19 integer NOT NULL DEFAULT '0', perm2 integer NOT NULL DEFAULT '0', perm20 integer NOT NULL DEFAULT '0', perm21 integer NOT NULL DEFAULT '0', perm22 integer NOT NULL DEFAULT '0', perm23 integer NOT NULL DEFAULT '0', perm24 integer NOT NULL DEFAULT '0', perm3 integer NOT NULL DEFAULT '0', perm4 integer NOT NULL DEFAULT '0', perm5 integer NOT NULL DEFAULT '0', perm6 integer NOT NULL DEFAULT '0', perm7 integer NOT NULL DEFAULT '0', perm8 integer NOT NULL DEFAULT '0', perm9 integer NOT NULL DEFAULT '0', privateTeamID bigint, rootID bigint, sourceListVersionNumber integer NOT NULL DEFAULT '0', syncHostUUID varchar(256), teamLeaderID bigint, _rowid bigint PRIMARY KEY NOT NULL, username varchar(64), deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX DLUser_abSyncGroupID_index ON DLUser (abSyncGroupID);
CREATE INDEX DLUser_assistantID_index ON DLUser (assistantID);
CREATE INDEX DLUser_contactID_index ON DLUser (contactID);
CREATE INDEX DLUser_privateTeamID_index ON DLUser (privateTeamID);
CREATE INDEX DLUser_teamLeaderID_index ON DLUser (teamLeaderID);
CREATE INDEX DLUser_deletionUserID_index ON DLUser (deletionUserID);
CREATE INDEX DLUser_deletionDate_index ON DLUser (deletionDate);
CREATE INDEX DLUser_deletionIdentifier_index ON DLUser (deletionIdentifier);
CREATE SEQUENCE DLUser_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY DLUser._rowid;
ALTER TABLE DLUser ALTER COLUMN _rowid SET DEFAULT nextval('DLUser_nextPK');
CREATE TRIGGER DLUser_timestamp_updating BEFORE INSERT OR UPDATE ON DLUser FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE MCUserDefaultsStorage (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, BlobValue bytea, HostID bigint, Key varchar, LastType integer NOT NULL DEFAULT '0', Value varchar, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX MCUserDefaultsStorage_HostID_index ON MCUserDefaultsStorage (HostID);
CREATE INDEX MCUserDefaultsStorage_deletionUserID_index ON MCUserDefaultsStorage (deletionUserID);
CREATE INDEX MCUserDefaultsStorage_deletionDate_index ON MCUserDefaultsStorage (deletionDate);
CREATE INDEX MCUserDefaultsStorage_deletionIdentifier_index ON MCUserDefaultsStorage (deletionIdentifier);
CREATE SEQUENCE MCUserDefaultsStorage_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY MCUserDefaultsStorage._rowid;
ALTER TABLE MCUserDefaultsStorage ALTER COLUMN _rowid SET DEFAULT nextval('MCUserDefaultsStorage_nextPK');
CREATE TRIGGER MCUserDefaultsStorage_timestamp_updating BEFORE INSERT OR UPDATE ON MCUserDefaultsStorage FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE UserLastSync (_timestamp timestamp with time zone, date timestamp with time zone, typeCode integer NOT NULL DEFAULT '0', userID bigint, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX UserLastSync_userID_index ON UserLastSync (userID);
CREATE INDEX UserLastSync_deletionUserID_index ON UserLastSync (deletionUserID);
CREATE INDEX UserLastSync_deletionDate_index ON UserLastSync (deletionDate);
CREATE INDEX UserLastSync_deletionIdentifier_index ON UserLastSync (deletionIdentifier);
CREATE SEQUENCE UserLastSync_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY UserLastSync._rowid;
ALTER TABLE UserLastSync ALTER COLUMN _rowid SET DEFAULT nextval('UserLastSync_nextPK');
CREATE TRIGGER UserLastSync_timestamp_updating BEFORE INSERT OR UPDATE ON UserLastSync FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE UserPreference (_timestamp timestamp with time zone, name varchar(128), prefValue varchar(4096), userID bigint, _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX UserPreference_deletionUserID_index ON UserPreference (deletionUserID);
CREATE INDEX UserPreference_deletionDate_index ON UserPreference (deletionDate);
CREATE INDEX UserPreference_deletionIdentifier_index ON UserPreference (deletionIdentifier);
CREATE SEQUENCE UserPreference_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY UserPreference._rowid;
ALTER TABLE UserPreference ALTER COLUMN _rowid SET DEFAULT nextval('UserPreference_nextPK');
CREATE TRIGGER UserPreference_timestamp_updating BEFORE INSERT OR UPDATE ON UserPreference FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE VisibilityPreset (_timestamp timestamp with time zone, name varchar(256), teamsPermissionCode varchar(4096), teamsWritePermissionCode varchar(4096), _rowid bigint PRIMARY KEY NOT NULL, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX VisibilityPreset_deletionUserID_index ON VisibilityPreset (deletionUserID);
CREATE INDEX VisibilityPreset_deletionDate_index ON VisibilityPreset (deletionDate);
CREATE INDEX VisibilityPreset_deletionIdentifier_index ON VisibilityPreset (deletionIdentifier);
CREATE SEQUENCE VisibilityPreset_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY VisibilityPreset._rowid;
ALTER TABLE VisibilityPreset ALTER COLUMN _rowid SET DEFAULT nextval('VisibilityPreset_nextPK');
CREATE TRIGGER VisibilityPreset_timestamp_updating BEFORE INSERT OR UPDATE ON VisibilityPreset FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE Reminder (_timestamp timestamp with time zone, active integer NOT NULL DEFAULT '0', archived integer NOT NULL DEFAULT '0', calendarID bigint, createDate timestamp with time zone, fireDatetime timestamp with time zone, firedDatetime timestamp with time zone, isDefaultForUserFlag integer NOT NULL DEFAULT '0', isRelativeFlag integer NOT NULL DEFAULT '0', measure integer NOT NULL DEFAULT '0', modifyDate timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, reminderSettings bytea, taskID bigint, timeblockID bigint, typeCode integer NOT NULL DEFAULT '0', unit integer NOT NULL DEFAULT '0', userID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX Reminder_deletionUserID_index ON Reminder (deletionUserID);
CREATE INDEX Reminder_deletionDate_index ON Reminder (deletionDate);
CREATE INDEX Reminder_deletionIdentifier_index ON Reminder (deletionIdentifier);
CREATE SEQUENCE Reminder_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY Reminder._rowid;
ALTER TABLE Reminder ALTER COLUMN _rowid SET DEFAULT nextval('Reminder_nextPK');
CREATE TRIGGER Reminder_timestamp_updating BEFORE INSERT OR UPDATE ON Reminder FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE MeetingInvite (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, userID bigint, statusCode integer NOT NULL DEFAULT '0', timeblockID bigint, deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX MeetingInvite_userID_index ON MeetingInvite (userID);
CREATE INDEX MeetingInvite_timeblockID_index ON MeetingInvite (timeblockID);
CREATE INDEX MeetingInvite_deletionUserID_index ON MeetingInvite (deletionUserID);
CREATE INDEX MeetingInvite_deletionDate_index ON MeetingInvite (deletionDate);
CREATE INDEX MeetingInvite_deletionIdentifier_index ON MeetingInvite (deletionIdentifier);
CREATE SEQUENCE MeetingInvite_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY MeetingInvite._rowid;
ALTER TABLE MeetingInvite ALTER COLUMN _rowid SET DEFAULT nextval('MeetingInvite_nextPK');
CREATE TRIGGER MeetingInvite_timestamp_updating BEFORE INSERT OR UPDATE ON MeetingInvite FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
CREATE TABLE OfflineConfiguration (_timestamp timestamp with time zone, _rowid bigint PRIMARY KEY NOT NULL, lastImportedChangeSetUUID varchar, lastExportedChangeSetUUID varchar, lastSyncDate timestamp with time zone, masterName varchar, masterHostAddress varchar, masterAlternateHostAddress varchar, masterHostPort integer, masterAlternateHostPort integer, isActive integer NOT NULL DEFAULT '0', statusCode integer NOT NULL DEFAULT '0', allowDMIFlag integer NOT NULL DEFAULT '0', fud timestamp with time zone, offlineUUID varchar(40), deletionUserID bigint, deletionDate timestamp with time zone, deletionIdentifier varchar(255));
CREATE INDEX OfflineConfiguration_deletionUserID_index ON OfflineConfiguration (deletionUserID);
CREATE INDEX OfflineConfiguration_deletionDate_index ON OfflineConfiguration (deletionDate);
CREATE INDEX OfflineConfiguration_deletionIdentifier_index ON OfflineConfiguration (deletionIdentifier);
CREATE SEQUENCE OfflineConfiguration_nextPK INCREMENT BY 1000 MINVALUE 1 NO MAXVALUE START WITH 1000 NO CYCLE OWNED BY OfflineConfiguration._rowid;
ALTER TABLE OfflineConfiguration ALTER COLUMN _rowid SET DEFAULT nextval('OfflineConfiguration_nextPK');
CREATE TRIGGER OfflineConfiguration_timestamp_updating BEFORE INSERT OR UPDATE ON OfflineConfiguration FOR EACH ROW EXECUTE PROCEDURE mc_timestamp_updating();
